@@ -2,7 +2,7 @@
  * input_ext-dec.h: structures exported to the VideoLAN decoders
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: input_ext-dec.h,v 1.54 2002/03/14 01:35:28 stef Exp $
+ * $Id: input_ext-dec.h,v 1.58 2002/05/18 17:47:46 sam Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Michel Kaempf <maxx@via.ecp.fr>
@@ -31,6 +31,11 @@
 /* These ones might violate the norm : */
 #define DVD_SPU_ES          0x82
 #define LPCM_AUDIO_ES       0x83
+#define MSMPEG4v1_VIDEO_ES  0x40
+#define MSMPEG4v2_VIDEO_ES  0x41
+#define MSMPEG4v3_VIDEO_ES  0x42
+#define MPEG4_VIDEO_ES      0x50
+
 #define UNKNOWN_ES          0xFF
 
 /* Structures exported to the decoders */
@@ -208,7 +213,7 @@ typedef struct bit_stream_s
 /*****************************************************************************
  * Prototypes from input_ext-dec.c
  *****************************************************************************/
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 void InitBitstream  ( struct bit_stream_s *, struct decoder_fifo_s *,
                       void (* pf_bitstream_callback)( struct bit_stream_s *,
                                                       boolean_t ),
@@ -234,7 +239,7 @@ void CurrentPTS( struct bit_stream_s *, mtime_t *, mtime_t * );
  * on a word boundary (XXX: there must be at least sizeof(WORD_TYPE) - 1
  * empty bytes in the bit buffer)
  *****************************************************************************/
-static __inline__ void AlignWord( bit_stream_t * p_bit_stream )
+static inline void AlignWord( bit_stream_t * p_bit_stream )
 {
     while( (ptrdiff_t)p_bit_stream->p_byte
              & (sizeof(WORD_TYPE) - 1) )
@@ -260,8 +265,8 @@ static __inline__ void AlignWord( bit_stream_t * p_bit_stream )
 /*****************************************************************************
  * ShowBits : return i_bits bits from the bit stream
  *****************************************************************************/
-static __inline__ u32 ShowBits( bit_stream_t * p_bit_stream,
-                                unsigned int i_bits )
+static inline u32 ShowBits( bit_stream_t * p_bit_stream,
+                            unsigned int i_bits )
 {
     if( p_bit_stream->fifo.i_available >= i_bits )
     {
@@ -283,8 +288,8 @@ static __inline__ u32 ShowBits( bit_stream_t * p_bit_stream,
  * ShowSignedBits : return i_bits bits from the bit stream, using signed
  *                  arithmetic
  *****************************************************************************/
-static __inline__ s32 ShowSignedBits( bit_stream_t * p_bit_stream,
-                                      unsigned int i_bits )
+static inline s32 ShowSignedBits( bit_stream_t * p_bit_stream,
+                                  unsigned int i_bits )
 {
     if( p_bit_stream->fifo.i_available >= i_bits )
     {
@@ -301,8 +306,8 @@ static __inline__ s32 ShowSignedBits( bit_stream_t * p_bit_stream,
  * RemoveBits : removes i_bits bits from the bit buffer
  *              XXX: do not use for 32 bits, see RemoveBits32
  *****************************************************************************/
-static __inline__ void RemoveBits( bit_stream_t * p_bit_stream,
-                                   unsigned int i_bits )
+static inline void RemoveBits( bit_stream_t * p_bit_stream,
+                               unsigned int i_bits )
 {
     p_bit_stream->fifo.i_available -= i_bits;
 
@@ -329,7 +334,7 @@ static __inline__ void RemoveBits( bit_stream_t * p_bit_stream,
  *                refill it)
  *****************************************************************************/
 #if (WORD_TYPE == u32)
-static __inline__ void RemoveBits32( bit_stream_t * p_bit_stream )
+static inline void RemoveBits32( bit_stream_t * p_bit_stream )
 {
     if( p_bit_stream->p_byte <= p_bit_stream->p_end - sizeof(WORD_TYPE) )
     {
@@ -356,8 +361,8 @@ static __inline__ void RemoveBits32( bit_stream_t * p_bit_stream )
  * GetBits : returns i_bits bits from the bit stream and removes them
  *           XXX: do not use for 32 bits, see GetBits32
  *****************************************************************************/
-static __inline__ u32 GetBits( bit_stream_t * p_bit_stream,
-                               unsigned int i_bits )
+static inline u32 GetBits( bit_stream_t * p_bit_stream,
+                           unsigned int i_bits )
 {
     u32             i_result;
 
@@ -393,8 +398,8 @@ static __inline__ u32 GetBits( bit_stream_t * p_bit_stream,
  *                 using signed arithmetic
  *                 XXX: do not use for 32 bits
  *****************************************************************************/
-static __inline__ s32 GetSignedBits( bit_stream_t * p_bit_stream,
-                                     unsigned int i_bits )
+static inline s32 GetSignedBits( bit_stream_t * p_bit_stream,
+                                 unsigned int i_bits )
 {
     if( p_bit_stream->fifo.i_available >= i_bits )
     {
@@ -416,7 +421,7 @@ static __inline__ s32 GetSignedBits( bit_stream_t * p_bit_stream,
  * GetBits32 : returns 32 bits from the bit stream and removes them
  *****************************************************************************/
 #if (WORD_TYPE == u32)
-static __inline__ u32 GetBits32( bit_stream_t * p_bit_stream )
+static inline u32 GetBits32( bit_stream_t * p_bit_stream )
 {
     u32             i_result;
 
@@ -456,7 +461,7 @@ static __inline__ u32 GetBits32( bit_stream_t * p_bit_stream )
 /*****************************************************************************
  * RealignBits : realigns the bit buffer on an 8-bit boundary
  *****************************************************************************/
-static __inline__ void RealignBits( bit_stream_t * p_bit_stream )
+static inline void RealignBits( bit_stream_t * p_bit_stream )
 {
     p_bit_stream->fifo.buffer <<= (p_bit_stream->fifo.i_available & 0x7);
     p_bit_stream->fifo.i_available &= ~0x7;
@@ -470,8 +475,8 @@ static __inline__ void RealignBits( bit_stream_t * p_bit_stream )
  * RealignBits(). p_buffer must point to a buffer at least as big as i_buf_len
  * otherwise your code will crash.
  *****************************************************************************/
-static __inline__ void GetChunk( bit_stream_t * p_bit_stream,
-                                 byte_t * p_buffer, size_t i_buf_len )
+static inline void GetChunk( bit_stream_t * p_bit_stream,
+                             byte_t * p_buffer, size_t i_buf_len )
 {
     ptrdiff_t           i_available;
 
@@ -540,7 +545,7 @@ typedef struct decoder_config_s
 /*****************************************************************************
  * Prototypes from input_dec.c
  *****************************************************************************/
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 void DecoderError      ( struct decoder_fifo_s * p_fifo );
 #else
 #   define DecoderError p_symbols->DecoderError
