@@ -2,7 +2,7 @@
  * modules.h : Module management functions.
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: modules.h,v 1.46 2002/03/20 03:43:51 sam Exp $
+ * $Id: modules.h,v 1.50 2002/05/18 17:47:46 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -26,7 +26,7 @@
  *****************************************************************************/
 
 /* Number of tries before we unload an unused module */
-#define MODULE_HIDE_DELAY 10000
+#define MODULE_HIDE_DELAY 50
 #define MODULE_SHORTCUT_MAX 10
 
 /* The module handle type. */
@@ -39,7 +39,7 @@ typedef void *  module_handle_t;
 /*****************************************************************************
  * Module capabilities.
  *****************************************************************************/
-static __inline__ char *GetCapabilityName( unsigned int i_capa )
+static inline char *GetCapabilityName( unsigned int i_capa )
 {
     /* The sole purpose of this inline function and the ugly #defines
      * around it is to avoid having two places to modify when adding a
@@ -96,7 +96,7 @@ typedef struct module_bank_s
                                     it is to design thread-safe linked lists */
 } module_bank_t;
 
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 extern module_bank_t *p_module_bank;
 #else
 #   define p_module_bank (p_symbols->p_module_bank)
@@ -130,9 +130,7 @@ typedef struct module_s
      * Variables set by the module to store its config options
      */
     struct module_config_s *p_config;      /* Module configuration structure */
-    struct module_config_s *p_config_orig;    /* original module config data */
     vlc_mutex_t            config_lock;    /* lock used to modify the config */
-    unsigned int           i_config_lines;  /* number of configuration lines */
     unsigned int           i_config_items;  /* number of configuration items */
 
     /*
@@ -337,7 +335,7 @@ typedef struct module_functions_s * p_module_functions_t;
 /*****************************************************************************
  * Exported functions.
  *****************************************************************************/
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 void            module_InitBank     ( void );
 void            module_LoadMain     ( void );
 void            module_LoadBuiltins ( void );
@@ -346,7 +344,7 @@ void            module_EndBank      ( void );
 void            module_ResetBank    ( void );
 void            module_ManageBank   ( void );
 module_t *      module_Need         ( int, char *, void * );
-void            module_Unneed       ( module_t * p_module );
+void            module_Unneed       ( module_t * );
 
 #else
 #   define module_Need p_symbols->module_Need
