@@ -2,7 +2,7 @@
  * modules_inner.h : Macros used from within a module.
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: modules_inner.h,v 1.13 2002/03/11 07:23:09 gbazin Exp $
+ * $Id: modules_inner.h,v 1.21 2002/05/22 17:17:45 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *
@@ -38,7 +38,7 @@
  * #define MODULE_STRING "foo"
  * #define MODULE_VAR(blah) "VLC_MODULE_foo_blah"
  *
- * and, if BUILTIN is set, we will also need:
+ * and, if __BUILTIN__ is set, we will also need:
  * #define MODULE_FUNC( zog ) module_foo_zog
  *
  * this can't easily be done with the C preprocessor, thus a few ugly hacks.
@@ -55,7 +55,7 @@
 
 /* If the module is built-in, then we need to define foo_InitModule instead
  * of InitModule. Same for Activate- and DeactivateModule. */
-#ifdef BUILTIN
+#ifdef __BUILTIN__
 #   define _M( function )          CONCATENATE( function, MODULE_NAME )
 #   define __VLC_SYMBOL( symbol )  CONCATENATE( symbol, MODULE_NAME )
 #   define DECLARE_SYMBOLS         ;
@@ -77,38 +77,44 @@
  */
 #define MODULE_INIT_START                                                     \
     DECLARE_SYMBOLS;                                                          \
-                                                                              \
     int __VLC_SYMBOL( InitModule ) ( module_t *p_module )                     \
     {                                                                         \
-        int i_shortcut = 0;                                                   \
+        int i_shortcut = 1;                                                   \
+        struct module_config_s* p_item;                                       \
+        STORE_SYMBOLS;                                                        \
         p_module->psz_name = MODULE_STRING;                                   \
         p_module->psz_longname = MODULE_STRING;                               \
         p_module->psz_program = NULL;                                         \
+        p_module->pp_shortcuts[ 0 ] = MODULE_STRING;                          \
         p_module->i_capabilities = 0;                                         \
-        p_module->i_cpu_capabilities = 0;
+        p_module->i_cpu_capabilities = 0;                                     \
+        do {
 
 #define MODULE_INIT_STOP                                                      \
-        STORE_SYMBOLS;                                                        \
+        } while( 0 );                                                         \
         p_module->pp_shortcuts[ i_shortcut ] = NULL;                          \
         p_module->i_config_items = 0;                                         \
-        for( p_module->i_config_lines = 0;                                    \
-             p_module->i_config_lines < (sizeof(p_config)/                    \
-                                            sizeof(module_config_t));         \
-             p_module->i_config_lines++ )                                     \
+        for( p_item = p_config;                                               \
+             p_item->i_type != MODULE_CONFIG_HINT_END;                        \
+             p_item++ )                                                       \
         {                                                                     \
-            if( p_config[p_module->i_config_lines].i_type &                   \
-                MODULE_CONFIG_ITEM )                                          \
+            if( p_item->i_type & MODULE_CONFIG_ITEM )                         \
                 p_module->i_config_items++;                                   \
         }                                                                     \
         vlc_mutex_init( &p_module->config_lock );                             \
-        p_module->p_config_orig = p_config;                                   \
-        p_module->p_config = config_Duplicate( p_module );                    \
+        p_module->p_config = config_Duplicate( p_config );                    \
         if( p_module->p_config == NULL )                                      \
         {                                                                     \
             intf_ErrMsg( MODULE_STRING                                        \
                          " InitModule error: can't duplicate p_config" );     \
             return( -1 );                                                     \
         }                                                                     \
+        for( p_item = p_module->p_config;                                     \
+             p_item->i_type != MODULE_CONFIG_HINT_END;                        \
+             p_item++ )                                                       \
+        {                                                                     \
+            p_item->p_lock = &p_module->config_lock;                          \
+        }                                                                     \
         return( 0 );                                                          \
     }
 
@@ -138,16 +144,18 @@
 #define MODULE_ACTIVATE_START                                                 \
     int __VLC_SYMBOL( ActivateModule ) ( module_t *p_module )                 \
     {                                                                         \
+        STORE_SYMBOLS;                                                        \
         p_module->p_functions =                                               \
           ( module_functions_t * )malloc( sizeof( module_functions_t ) );     \
-        p_module->p_config_orig = p_config;                                   \
         if( p_module->p_functions == NULL )                                   \
         {                                                                     \
             return( -1 );                                                     \
         }                                                                     \
-        STORE_SYMBOLS;
+        config_SetCallbacks( p_module->p_config, p_config );                  \
+        do {
 
 #define MODULE_ACTIVATE_STOP                                                  \
+        } while( 0 );                                                         \
         return( 0 );                                                          \
     }
 
@@ -159,9 +167,11 @@
 #define MODULE_DEACTIVATE_START                                               \
     int __VLC_SYMBOL( DeactivateModule )( module_t *p_module )                \
     {                                                                         \
-        p_module->p_config_orig = NULL;                                       \
-        free( p_module->p_functions );
+        free( p_module->p_functions );                                        \
+        do {
 
 #define MODULE_DEACTIVATE_STOP                                                \
+        } while( 0 );                                                         \
+        config_UnsetCallbacks( p_module->p_config );                          \
         return( 0 );                                                          \
     }
