@@ -2,7 +2,7 @@
  * ac3_adec.c: ac3 decoder module main file
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: ac3_adec.c,v 1.24 2002/04/05 01:05:22 gbazin Exp $
+ * $Id: ac3_adec.c,v 1.30 2002/05/15 19:36:04 sam Exp $
  *
  * Authors: Michel Lespinasse <walken@zoy.org>
  *
@@ -69,20 +69,20 @@ void _M( adec_getfunctions )( function_list_t * p_function_list )
  * Build configuration tree.
  *****************************************************************************/
 /* Variable containing the AC3 downmix method */
-#define DOWNMIX_METHOD_VAR              "ac3_downmix"
+#define DOWNMIX_METHOD_VAR              "ac3-downmix"
 /* Variable containing the AC3 IMDCT method */
-#define IMDCT_METHOD_VAR                "ac3_imdct"
+#define IMDCT_METHOD_VAR                "ac3-imdct"
 
 MODULE_CONFIG_START
-ADD_CATEGORY_HINT( "Misc Options", NULL)
-ADD_PLUGIN  ( DOWNMIX_METHOD_VAR, MODULE_CAPABILITY_DOWNMIX, NULL, NULL,
-              "AC3 downmix method", NULL )
-ADD_PLUGIN  ( IMDCT_METHOD_VAR, MODULE_CAPABILITY_IMDCT, NULL, NULL,
-              "AC3 IMDCT method", NULL )
+ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL)
+ADD_MODULE  ( DOWNMIX_METHOD_VAR, MODULE_CAPABILITY_DOWNMIX, NULL, NULL,
+              N_("AC3 downmix module"), NULL )
+ADD_MODULE  ( IMDCT_METHOD_VAR, MODULE_CAPABILITY_IMDCT, NULL, NULL,
+              N_("AC3 IMDCT module"), NULL )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "software AC3 decoder" )
+    SET_DESCRIPTION( _("software AC3 decoder") )
     ADD_CAPABILITY( DECODER, 50 )
     ADD_SHORTCUT( "ac3_adec" )
     ADD_SHORTCUT( "ac3" )
@@ -119,8 +119,10 @@ static int InitThread( ac3dec_thread_t * p_ac3thread )
      * Thread properties 
      */
     p_ac3thread->p_fifo = p_ac3thread->p_config->p_decoder_fifo;
+
     p_ac3thread->ac3_decoder =
-        vlc_memalign( 16, sizeof(ac3dec_t), &p_ac3thread->ac3_decoder_orig );
+        vlc_memalign( &p_ac3thread->ac3_decoder_orig, 16, sizeof(ac3dec_t) );
+    memset( p_ac3thread->ac3_decoder, 0, sizeof( ac3dec_t ) );
 
     /*
      * Choose the best downmix module
@@ -153,7 +155,7 @@ static int InitThread( ac3dec_thread_t * p_ac3thread )
      * Choose the best IMDCT module
      */
     p_ac3thread->ac3_decoder->imdct =
-    vlc_memalign( 16, sizeof(imdct_t), &p_ac3thread->ac3_decoder->imdct_orig );
+    vlc_memalign( &p_ac3thread->ac3_decoder->imdct_orig, 16, sizeof(imdct_t) );
     
 #define IMDCT p_ac3thread->ac3_decoder->imdct
     psz_name = config_GetPszVariable( IMDCT_METHOD_VAR );
@@ -180,41 +182,42 @@ static int InitThread( ac3dec_thread_t * p_ac3thread )
 
     /* Initialize the ac3 decoder structures */
     p_ac3thread->ac3_decoder->samples =
-        vlc_memalign( 16, 6 * 256 * sizeof(float),
-                      &p_ac3thread->ac3_decoder->samples_orig );
+        vlc_memalign( &p_ac3thread->ac3_decoder->samples_orig,
+                      16, 6 * 256 * sizeof(float) );
 
-    IMDCT->buf    = vlc_memalign( 16, N/4 * sizeof(complex_t),
-                                  &IMDCT->buf_orig );
-    IMDCT->delay  = vlc_memalign( 16, 6 * 256 * sizeof(float),
-                                  &IMDCT->delay_orig );
-    IMDCT->delay1 = vlc_memalign( 16, 6 * 256 * sizeof(float),
-                                  &IMDCT->delay1_orig );
-    IMDCT->xcos1  = vlc_memalign( 16, N/4 * sizeof(float),
-                                  &IMDCT->xcos1_orig );
-    IMDCT->xsin1  = vlc_memalign( 16, N/4 * sizeof(float),
-                                  &IMDCT->xsin1_orig );
-    IMDCT->xcos2  = vlc_memalign( 16, N/8 * sizeof(float),
-                                  &IMDCT->xcos2_orig );
-    IMDCT->xsin2  = vlc_memalign( 16, N/8 * sizeof(float),
-                                  &IMDCT->xsin2_orig );
-    IMDCT->xcos_sin_sse = vlc_memalign( 16, 128 * 4 * sizeof(float),
-                                        &IMDCT->xcos_sin_sse_orig );
-    IMDCT->w_1    = vlc_memalign( 16, 1  * sizeof(complex_t),
-                                  &IMDCT->w_1_orig );
-    IMDCT->w_2    = vlc_memalign( 16, 2  * sizeof(complex_t),
-                                  &IMDCT->w_2_orig );
-    IMDCT->w_4    = vlc_memalign( 16, 4  * sizeof(complex_t),
-                                  &IMDCT->w_4_orig );
-    IMDCT->w_8    = vlc_memalign( 16, 8  * sizeof(complex_t),
-                                  &IMDCT->w_8_orig );
-    IMDCT->w_16   = vlc_memalign( 16, 16 * sizeof(complex_t),
-                                  &IMDCT->w_16_orig );
-    IMDCT->w_32   = vlc_memalign( 16, 32 * sizeof(complex_t),
-                                  &IMDCT->w_32_orig );
-    IMDCT->w_64   = vlc_memalign( 16, 64 * sizeof(complex_t),
-                                  &IMDCT->w_64_orig );
+    IMDCT->buf    = vlc_memalign( &IMDCT->buf_orig,
+                                  16, N/4 * sizeof(complex_t) );
+    IMDCT->delay  = vlc_memalign( &IMDCT->delay_orig,
+                                  16, 6 * 256 * sizeof(float) );
+    IMDCT->delay1 = vlc_memalign( &IMDCT->delay1_orig,
+                                  16, 6 * 256 * sizeof(float) );
+    IMDCT->xcos1  = vlc_memalign( &IMDCT->xcos1_orig,
+                                  16, N/4 * sizeof(float) );
+    IMDCT->xsin1  = vlc_memalign( &IMDCT->xsin1_orig,
+                                  16, N/4 * sizeof(float) );
+    IMDCT->xcos2  = vlc_memalign( &IMDCT->xcos2_orig,
+                                  16, N/8 * sizeof(float) );
+    IMDCT->xsin2  = vlc_memalign( &IMDCT->xsin2_orig,
+                                  16, N/8 * sizeof(float) );
+    IMDCT->xcos_sin_sse = vlc_memalign( &IMDCT->xcos_sin_sse_orig,
+                                        16, 128 * 4 * sizeof(float) );
+    IMDCT->w_1    = vlc_memalign( &IMDCT->w_1_orig,
+                                  16, 1  * sizeof(complex_t) );
+    IMDCT->w_2    = vlc_memalign( &IMDCT->w_2_orig,
+                                  16, 2  * sizeof(complex_t) );
+    IMDCT->w_4    = vlc_memalign( &IMDCT->w_4_orig,
+                                  16, 4  * sizeof(complex_t) );
+    IMDCT->w_8    = vlc_memalign( &IMDCT->w_8_orig,
+                                  16, 8  * sizeof(complex_t) );
+    IMDCT->w_16   = vlc_memalign( &IMDCT->w_16_orig,
+                                  16, 16 * sizeof(complex_t) );
+    IMDCT->w_32   = vlc_memalign( &IMDCT->w_32_orig,
+                                  16, 32 * sizeof(complex_t) );
+    IMDCT->w_64   = vlc_memalign( &IMDCT->w_64_orig,
+                                  16, 64 * sizeof(complex_t) );
+#undef IMDCT
 
-    ac3_init( p_ac3thread->ac3_decoder );
+    _M( ac3_init )( p_ac3thread->ac3_decoder );
 
     /*
      * Initialize the output properties
@@ -241,8 +244,8 @@ static int decoder_Run ( decoder_config_t * p_config )
     boolean_t           b_sync = 0;
 
     /* Allocate the memory needed to store the thread's structure */
-    p_ac3thread = (ac3dec_thread_t *)vlc_memalign( 16,
-                      sizeof(ac3dec_thread_t), &p_ac3thread_orig );
+    p_ac3thread = (ac3dec_thread_t *)vlc_memalign( &p_ac3thread_orig, 16,
+                                                   sizeof(ac3dec_thread_t) );
 
     if( p_ac3thread == NULL )
     {
@@ -314,37 +317,14 @@ static int decoder_Run ( decoder_config_t * p_config )
         }
 
         /* Creating the audio output fifo if not created yet */
-        if (p_ac3thread->p_aout_fifo == NULL ) {
+        if (p_ac3thread->p_aout_fifo == NULL )
+        {
             p_ac3thread->p_aout_fifo = aout_CreateFifo( AOUT_FIFO_PCM, 2,
                            sync_info.sample_rate, AC3DEC_FRAME_SIZE, NULL  );
             if ( p_ac3thread->p_aout_fifo == NULL )
             {
-                free( IMDCT->w_1_orig );
-                free( IMDCT->w_64_orig );
-                free( IMDCT->w_32_orig );
-                free( IMDCT->w_16_orig );
-                free( IMDCT->w_8_orig );
-                free( IMDCT->w_4_orig );
-                free( IMDCT->w_2_orig );
-                free( IMDCT->xcos_sin_sse_orig );
-                free( IMDCT->xsin2_orig );
-                free( IMDCT->xcos2_orig );
-                free( IMDCT->xsin1_orig );
-                free( IMDCT->xcos1_orig );
-                free( IMDCT->delay1_orig );
-                free( IMDCT->delay_orig );
-                free( IMDCT->buf_orig );
-        #undef IMDCT
-
-                free( p_ac3thread->ac3_decoder->samples_orig );
-        
-                module_Unneed( p_ac3thread->ac3_decoder->imdct->p_module );
-                module_Unneed( p_ac3thread->ac3_decoder->downmix.p_module );
-        
-                free( p_ac3thread->ac3_decoder->imdct_orig );
-                free( p_ac3thread->ac3_decoder_orig );
-        
-                return( -1 );
+                p_ac3thread->p_fifo->b_error = 1;
+                break;
             }
         }
 
