@@ -2,7 +2,7 @@
  * ac3_spdif.c: ac3 pass-through to external decoder with enabled soundcard
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: ac3_spdif.c,v 1.21 2002/03/15 01:47:16 stef Exp $
+ * $Id: ac3_spdif.c,v 1.24 2002/05/17 18:01:25 stef Exp $
  *
  * Authors: Stphane Borel <stef@via.ecp.fr>
  *          Juha Yrjola <jyrjola@cc.hut.fi>
@@ -116,7 +116,7 @@ MODULE_CONFIG_START
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "SPDIF pass-through AC3 decoder" )
+    SET_DESCRIPTION( _("SPDIF pass-through AC3 decoder") )
     ADD_CAPABILITY( DECODER, 0 )
     ADD_SHORTCUT( "ac3_spdif" )
     ADD_SHORTCUT( "pass_through" )
@@ -223,9 +223,13 @@ static int decoder_Run( decoder_config_t * p_config )
          * Therefore a non-zero value after a call to GetBits() means the PES
          * has changed. */
         b_sync = 0;
-        while( !b_sync )
+        while( !p_spdif->p_fifo->b_die
+            && !p_spdif->p_fifo->b_error
+            && !b_sync )
         {
-            while( GetBits( &p_spdif->bit_stream, 8 ) != 0x0b );
+            while( !p_spdif->p_fifo->b_die
+                && !p_spdif->p_fifo->b_error
+                && GetBits( &p_spdif->bit_stream, 8 ) != 0x0b );
             p_spdif->i_real_pts = p_spdif->i_pts;
             p_spdif->i_pts = 0;
             b_sync = ( ShowBits( &p_spdif->bit_stream, 8 ) == 0x77 );
@@ -273,13 +277,23 @@ static int InitThread( ac3_spdif_thread_t * p_spdif )
                    BitstreamCallback, (void*)p_spdif );
 
     /* Find syncword */
-    while( !b_sync )
+    while( !p_spdif->p_fifo->b_die
+        && !p_spdif->p_fifo->b_error
+        && !b_sync )
     {
-        while( GetBits( &p_spdif->bit_stream, 8 ) != 0x0b );
+        while( !p_spdif->p_fifo->b_die
+            && !p_spdif->p_fifo->b_error
+            && GetBits( &p_spdif->bit_stream, 8 ) != 0x0b );
         p_spdif->i_real_pts = p_spdif->i_pts;
         p_spdif->i_pts = 0;
         b_sync = ( ShowBits( &p_spdif->bit_stream, 8 ) == 0x77 );
     }
+
+    if( p_spdif->p_fifo->b_die || p_spdif->p_fifo->b_error )
+    {
+        return -1;
+    }
+
     RemoveBits( &p_spdif->bit_stream, 8 );
 
     /* Check stream properties */
@@ -300,8 +314,8 @@ static int InitThread( ac3_spdif_thread_t * p_spdif )
     }
 
     /* The audio output need to be ready for an ac3 stream */
-    p_spdif->i_previous_format = config_GetIntVariable( "aout_format" );
-    config_PutIntVariable( "aout_format", 8 );
+    p_spdif->i_previous_format = config_GetIntVariable( "audio-format" );
+    config_PutIntVariable( "audio-format", 8 );
     
     /* Creating the audio output fifo */
     p_spdif->p_aout_fifo = aout_CreateFifo( AOUT_FIFO_SPDIF, 1,
@@ -351,7 +365,7 @@ static void EndThread( ac3_spdif_thread_t * p_spdif )
     }
 
     /* restore previous setting for output format */
-    config_PutIntVariable( "aout_format", p_spdif->i_previous_format );
+    config_PutIntVariable( "audio-format", p_spdif->i_previous_format );
 
     /* Destroy descriptor */
     free( p_spdif );
@@ -362,8 +376,8 @@ static void EndThread( ac3_spdif_thread_t * p_spdif )
  *****************************************************************************
  * This function is called by input's NextDataPacket.
  *****************************************************************************/
-static void BitstreamCallback ( bit_stream_t * p_bit_stream,
-                                        boolean_t b_new_pes)
+static void BitstreamCallback( bit_stream_t * p_bit_stream,
+                               boolean_t      b_new_pes )
 {
     ac3_spdif_thread_t *    p_spdif;
 
