@@ -2,7 +2,7 @@
  * vout_events.c: Windows DirectX video output events handler
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: vout_events.c,v 1.13 2002/04/02 06:31:23 gbazin Exp $
+ * $Id: vout_events.c,v 1.18 2002/05/18 22:41:43 gbazin Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -66,7 +66,8 @@ static long FAR PASCAL DirectXEventProc ( HWND hwnd, UINT message,
  *****************************************************************************/
 void DirectXEventThread( vout_thread_t *p_vout )
 {
-    MSG             msg;
+    MSG msg;
+    POINT old_mouse_pos;
 
     /* Initialisation */
 
@@ -99,28 +100,38 @@ void DirectXEventThread( vout_thread_t *p_vout )
         switch( msg.message )
         {
 
+        case WM_NCMOUSEMOVE:
         case WM_MOUSEMOVE:
-            if( p_vout->p_sys->b_cursor )
+            if( (abs(GET_X_LPARAM(msg.lParam) - old_mouse_pos.x) > 2 ||
+                (abs(GET_Y_LPARAM(msg.lParam) - old_mouse_pos.y)) > 2 ) )
             {
-                if( p_vout->p_sys->b_cursor_autohidden )
+                GetCursorPos( &old_mouse_pos );
+                p_vout->p_sys->i_lastmoved = mdate();
+
+                if( p_vout->p_sys->b_cursor_hidden )
                 {
-                    p_vout->p_sys->b_cursor_autohidden = 0;
-                    p_vout->p_sys->i_lastmoved = mdate();
+                    p_vout->p_sys->b_cursor_hidden = 0;
                     ShowCursor( TRUE );
                 }
-                else
-                {
-                    p_vout->p_sys->i_lastmoved = mdate();
-                }
             }
-            DispatchMessage(&msg);
+            break;
+
+        case WM_VLC_HIDE_MOUSE:
+            GetCursorPos( &old_mouse_pos );
+            ShowCursor( FALSE );
             break;
 
         case WM_RBUTTONUP:
-            intf_WarnMsg( 4, "vout: vout_Manage WM_RBUTTONUP" );
             p_main->p_intf->b_menu_change = 1;
             break;
 
+        case WM_LBUTTONDOWN:
+            break;
+
+        case WM_LBUTTONDBLCLK:
+            p_vout->p_sys->i_changes |= VOUT_FULLSCREEN_CHANGE;
+            break;
+
         case WM_KEYDOWN:
             /* the key events are first processed here. The next
              * message processed by this main message loop will be the
@@ -138,7 +149,6 @@ void DirectXEventThread( vout_thread_t *p_vout )
             break;
 
         case WM_CHAR:
-            intf_WarnMsg( 3, "vout: vout_Manage WM_CHAR" );
             switch( msg.wParam )
             {
             case 'q':
@@ -193,10 +203,6 @@ void DirectXEventThread( vout_thread_t *p_vout )
         default:
             /* Messages we don't handle directly are dispatched to the
              * window procedure */
-#if 0
-            intf_WarnMsg( 5, "vout: vout_Manage unhandled message",
-                          msg.message );
-#endif
             TranslateMessage(&msg);
             DispatchMessage(&msg);
             break;
@@ -281,33 +287,43 @@ static int DirectXCreateWindow( vout_thread_t *p_vout )
     ReleaseDC( p_vout->p_sys->hwnd, hdc );
 
     /* Get the Icon from the main app */
+    vlc_icon = NULL;
     if( GetModuleFileName( NULL, vlc_path, _MAX_PATH ) )
     {
         vlc_icon = ExtractIcon( hInstance, vlc_path, 0 );
     }
-    if( !vlc_icon )
-        vlc_icon = LoadIcon( NULL, IDI_APPLICATION );
 
 
     /* fill in the window class structure */
     wc.cbSize        = sizeof(WNDCLASSEX);
-    wc.style         = 0;                               /* no special styles */
+    wc.style         = CS_DBLCLKS;                       /* style: dbl click */
     wc.lpfnWndProc   = (WNDPROC)DirectXEventProc;           /* event handler */
     wc.cbClsExtra    = 0;                             /* no extra class data */
     wc.cbWndExtra    = 0;                            /* no extra window data */
     wc.hInstance     = hInstance;                                /* instance */
-    wc.hIcon         = CopyIcon( vlc_icon );            /* load the vlc icon */
+    wc.hIcon         = vlc_icon;                        /* load the vlc icon */
     wc.hCursor       = LoadCursor(NULL, IDC_ARROW); /* load a default cursor */
     wc.hbrBackground = p_vout->p_sys->hbrush;            /* background color */
     wc.lpszMenuName  = NULL;                                      /* no menu */
     wc.lpszClassName = "VLC DirectX";                 /* use a special class */
-    wc.hIconSm       = CopyIcon( vlc_icon );            /* load the vlc icon */
+    wc.hIconSm       = vlc_icon;                        /* load the vlc icon */
 
     /* register the window class */
     if (!RegisterClassEx(&wc))
     {
-        /* Check why it failed. If it's because one already exists then fine */
         WNDCLASS wndclass;
+
+        /* free window background brush */
+        if( p_vout->p_sys->hbrush )
+        {
+            DeleteObject( p_vout->p_sys->hbrush );
+            p_vout->p_sys->hbrush = NULL;
+        }
+
+        if( vlc_icon )
+            DestroyIcon( vlc_icon );
+
+        /* Check why it failed. If it's because one already exists then fine */
         if( !GetClassInfo( hInstance, "VLC DirectX", &wndclass ) )
         {
             intf_ErrMsg( "vout: DirectXCreateWindow RegisterClass FAILED" );
@@ -363,22 +379,22 @@ static int DirectXCreateWindow( vout_thread_t *p_vout )
 static void DirectXCloseWindow( vout_thread_t *p_vout )
 {
     intf_WarnMsg( 3, "vout: DirectXCloseWindow" );
+
+    vlc_mutex_lock( &p_vout->p_sys->event_thread_lock );
+
     if( p_vout->p_sys->hwnd != NULL )
     {
-        DestroyWindow( p_vout->p_sys->hwnd);
+        DestroyWindow( p_vout->p_sys->hwnd );
         p_vout->p_sys->hwnd = NULL;
     }
 
+    p_vout->p_sys->i_event_thread_status = THREAD_OVER;
+
+    vlc_mutex_unlock( &p_vout->p_sys->event_thread_lock );
+
     /* We don't unregister the Window Class because it could lead to race
      * conditions and it will be done anyway by the system when the app will
      * exit */
-
-    /* free window background brush */
-    if( p_vout->p_sys->hbrush != NULL )
-    {
-        DeleteObject( p_vout->p_sys->hbrush );
-        p_vout->p_sys->hbrush = NULL;
-    }
 }
 
 /*****************************************************************************
@@ -499,12 +515,6 @@ static long FAR PASCAL DirectXEventProc( HWND hwnd, UINT message,
         GetClientRect( hwnd, &rect_window );
         p_vout->p_sys->i_window_width = rect_window.right;
         p_vout->p_sys->i_window_height = rect_window.bottom;
-#if 0
-        intf_WarnMsg( 3, "vout: WinProc WM_WINDOWPOSCHANGED %i,%i,%i,%i",
-                      p_vout->p_sys->i_window_x, p_vout->p_sys->i_window_y,
-                      p_vout->p_sys->i_window_width,
-                      p_vout->p_sys->i_window_height );
-#endif
 
         DirectXUpdateRects( p_vout );
         if( p_vout->p_sys->b_using_overlay &&
@@ -512,20 +522,14 @@ static long FAR PASCAL DirectXEventProc( HWND hwnd, UINT message,
             DirectXUpdateOverlay( p_vout );
 
         /* signal the size change */
-        p_vout->p_sys->i_changes |= VOUT_SIZE_CHANGE;
+        if( !p_vout->p_sys->b_using_overlay &&
+            !p_vout->p_sys->b_event_thread_die )
+            p_vout->p_sys->i_changes |= VOUT_SIZE_CHANGE;
 
         return 0;
         }
         break;
 
-    case WM_ACTIVATE:
-        intf_WarnMsg( 4, "vout: WinProc WM_ACTIVATE" );
-        break;
-
-    case WM_CREATE:
-        intf_WarnMsg( 4, "vout: WinProc WM_CREATE" );
-        break;
-
     /* the user wants to close the window */
     case WM_CLOSE:
         intf_WarnMsg( 4, "vout: WinProc WM_CLOSE" );
@@ -534,14 +538,6 @@ static long FAR PASCAL DirectXEventProc( HWND hwnd, UINT message,
         return 0;
         break;
 
-    /* the window has been closed so shut down everything now */
-    case WM_DESTROY:
-        intf_WarnMsg( 4, "vout: WinProc WM_DESTROY" );
-        /* just destroy the window */
-        PostQuitMessage( 0 );
-        return 0;
-        break;
-
     case WM_SYSCOMMAND:
         switch (wParam)
         {
@@ -552,12 +548,6 @@ static long FAR PASCAL DirectXEventProc( HWND hwnd, UINT message,
         }
         break;
 
-#if 0
-    case WM_PAINT:
-        intf_WarnMsg( 4, "vout: WinProc WM_PAINT" );
-        break;
-#endif
-
     case WM_ERASEBKGND:
         p_vout = (vout_thread_t *)GetWindowLong( hwnd, GWL_USERDATA );
         if( !p_vout->p_sys->b_using_overlay )
@@ -580,11 +570,9 @@ static long FAR PASCAL DirectXEventProc( HWND hwnd, UINT message,
         }
         break;
 
-#if 0
     default:
-        intf_WarnMsg( 4, "vout: WinProc WM Default %i", message );
+        //intf_WarnMsg( 4, "vout: WinProc WM Default %i", message );
         break;
-#endif
     }
 
     return DefWindowProc(hwnd, message, wParam, lParam);
