@@ -2,7 +2,7 @@
  * ggi.c : GGI plugin for vlc
  *****************************************************************************
  * Copyright (C) 2000, 2001 VideoLAN
- * $Id: ggi.c,v 1.19 2002/03/25 19:16:20 gbazin Exp $
+ * $Id: ggi.c,v 1.20 2002/04/19 13:56:11 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -59,13 +59,13 @@ static void SetPalette     ( vout_thread_t *, u16 *, u16 *, u16 * );
 /*****************************************************************************
  * Building configuration tree
  *****************************************************************************/
-#define DISPLAY_TEXT "X11 display name"
-#define DISPLAY_LONGTEXT "Specify the X11 hardware display you want to use.\n"\
-                         "By default vlc will use the value of the DISPLAY " \
-                         "environment variable."
+#define DISPLAY_TEXT N_("X11 display name")
+#define DISPLAY_LONGTEXT N_("Specify the X11 hardware display you want to use."\
+                           "\nBy default vlc will use the value of the DISPLAY"\
+                           " environment variable.")
 
 MODULE_CONFIG_START
-ADD_CATEGORY_HINT( "Miscellaneous", NULL )
+ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL )
 ADD_STRING  ( "ggi_display", NULL, NULL, DISPLAY_TEXT, DISPLAY_LONGTEXT )
 MODULE_CONFIG_STOP
 
