@@ -2,10 +2,10 @@
  * gnome.c : Gnome plugin for vlc
  *****************************************************************************
  * Copyright (C) 2000 VideoLAN
- * $Id: gnome.c,v 1.16 2002/03/31 22:35:44 gbazin Exp $
+ * $Id: gnome.c,v 1.21 2002/05/22 14:20:41 gbazin Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
- *      
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -61,24 +61,28 @@ static gint GnomeManage      ( gpointer p_data );
 /*****************************************************************************
  * Building configuration tree
  *****************************************************************************/
-#define TOOLTIPS_TEXT "hide tooltips"
-#define TOOLTIPS_LONGTEXT "Do not show tooltips for configuration options"
+#define TOOLTIPS_TEXT N_("hide tooltips")
+#define TOOLTIPS_LONGTEXT N_("Do not show tooltips for configuration options.")
+#define TOOLBAR_TEXT N_("hide text on toolbar buttons")
+#define TOOLBAR_LONGTEXT N_("Do not show the text below icons on the toolbar.")
 
-#define PREFS_MAXH_TEXT "maximum height for the configuration windows"
-#define PREFS_MAXH_LONGTEXT "You can set the maximum height that the " \
-                            "configuration windows in the prefences menu " \
-                            "will take"
+#define PREFS_MAXH_TEXT N_("maximum height for the configuration windows")
+#define PREFS_MAXH_LONGTEXT N_( \
+    "You can set the maximum height that the configuration windows in the " \
+    "preferences menu will occupy.")
 
 MODULE_CONFIG_START
-    ADD_CATEGORY_HINT( "Misc Options", NULL )
-    ADD_BOOL    ( "gnome_hide_tooltips", NULL, TOOLTIPS_TEXT,
+    ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL )
+    ADD_BOOL    ( "gnome-notooltips", GtkHideTooltips, TOOLTIPS_TEXT,
                   TOOLTIPS_LONGTEXT )
-    ADD_INTEGER ( "gnome_prefs_maxh", 480, NULL, PREFS_MAXH_TEXT,
+    ADD_BOOL    ( "gnome-notoolbartext", GtkHideToolbarText, TOOLBAR_TEXT,
+                  TOOLBAR_LONGTEXT )
+    ADD_INTEGER ( "gnome-prefs-maxh", 480, NULL, PREFS_MAXH_TEXT,
                   PREFS_MAXH_LONGTEXT )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "Gnome interface module" )
+    SET_DESCRIPTION( _("Gnome interface module") )
 #ifndef WIN32
     if( getenv( "DISPLAY" ) == NULL )
     {
@@ -167,6 +171,8 @@ static int intf_Open( intf_thread_t *p_intf )
 
     p_intf->p_sys->pf_callback[0] = NULL;
 
+    p_intf->p_sys->i_part = 0;
+
     return( 0 );
 }
 
@@ -266,9 +272,15 @@ static void intf_Run( intf_thread_t *p_intf )
     p_intf->p_sys->p_tooltips = gtk_tooltips_new();
 
     /* Hide tooltips if the option is set */
-    if( config_GetIntVariable( "gnome_hide_tooltips" ) )
+    if( config_GetIntVariable( "gnome-notooltips" ) )
         gtk_tooltips_disable( p_intf->p_sys->p_tooltips );
 
+    /* Hide toolbar text of the option is set */
+    if ( config_GetIntVariable( "gnome-notoolbartext" ) )
+        gtk_toolbar_set_style(
+            GTK_TOOLBAR(lookup_widget( p_intf->p_sys->p_window, "toolbar" )),
+            GTK_TOOLBAR_ICONS );
+
     /* Store p_intf to keep an eye on it */
     gtk_object_set_data( GTK_OBJECT(p_intf->p_sys->p_window),
                          "p_intf", p_intf );
@@ -385,7 +397,7 @@ static gint GnomeManage( gpointer p_data )
     }
 
     /* Update the playlist */
-    GtkPlayListManage( p_intf ); 
+    GtkPlayListManage( p_intf );
 
     if( p_input_bank->pp_input[0] != NULL && !p_intf->b_die )
     {
@@ -407,7 +419,7 @@ static gint GnomeManage( gpointer p_data )
             {
                 float           newvalue;
                 newvalue = p_intf->p_sys->p_adj->value;
-    
+
 #define p_area p_input_bank->pp_input[0]->stream.p_selected_area
                 /* If the user hasn't touched the slider since the last time,
                  * then the input can safely change it */
@@ -416,7 +428,7 @@ static gint GnomeManage( gpointer p_data )
                     /* Update the value */
                     p_intf->p_sys->p_adj->value = p_intf->p_sys->f_adj_oldvalue =
                         ( 100. * p_area->i_tell ) / p_area->i_size;
-    
+
                     gtk_signal_emit_by_name( GTK_OBJECT( p_intf->p_sys->p_adj ),
                                              "value_changed" );
                 }
@@ -425,11 +437,11 @@ static gint GnomeManage( gpointer p_data )
                 else if( p_intf->p_sys->b_slider_free )
                 {
                     off_t i_seek = ( newvalue * p_area->i_size ) / 100;
-        
+
                     vlc_mutex_unlock( &p_input_bank->pp_input[0]->stream.stream_lock );
                     input_Seek( p_input_bank->pp_input[0], i_seek );
                     vlc_mutex_lock( &p_input_bank->pp_input[0]->stream.stream_lock );
-    
+
                     /* Update the old value */
                     p_intf->p_sys->f_adj_oldvalue = newvalue;
                 }
