@@ -2,7 +2,7 @@
  * intf_controller.h: MacOS X plugin for vlc
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: intf_controller.h,v 1.4 2002/03/19 03:33:52 jlj Exp $
+ * $Id: intf_controller.h,v 1.8 2002/05/20 05:20:12 jlj Exp $
  *
  * Authors: Florian G. Pflug <fgp@phlo.org>
  *
@@ -54,26 +54,33 @@
     IBOutlet NSButton       *o_stepr;
     IBOutlet NSButton       *o_stepf;
     IBOutlet NSSlider       *o_timeslider;
-    IBOutlet NSTextField    *o_currenttime;
-    IBOutlet NSMenuItem     *o_menu_fs;
+    IBOutlet NSTextField    *o_time;
 
     IBOutlet Intf_PlaylistDS *o_playlistds;
 }
 
 /* Initialization & Event-Management */
 - (void)awakeFromNib;
-- (void)applicationDidFinishLaunching:(NSNotification *)o_notification;
 - (void)manage;
 - (void)terminate;
 
+/* NSApplication messages */
+- (void)applicationWillFinishLaunching:(NSNotification *)o_notification;
+- (BOOL)application:(NSApplication *)o_app openFile:(NSString *)o_filename;
+
 /* Functions atteched to user interface */
-- (IBAction)openFile:(id)sender;
 - (IBAction)pause:(id)sender;
 - (IBAction)play:(id)sender;
 - (IBAction)stop:(id)sender;
-- (IBAction)timeslider_update:(id)slider;
-- (IBAction)speedslider_update:(id)slider;
-- (IBAction)fullscreen_toggle:(id)sender;
+- (IBAction)faster:(id)sender;
+- (IBAction)slower:(id)sender;
+- (IBAction)prev:(id)sender;
+- (IBAction)next:(id)sender;
+- (IBAction)mute:(id)sender;
+- (IBAction)fullscreen:(id)fullscreen;
+- (IBAction)eject:(id)sender;
+- (IBAction)maxvolume:(id)sender;
+- (IBAction)timesliderUpdate:(id)slider;
 - (IBAction)quit:(id)sender;
 
 @end
