@@ -2,7 +2,7 @@
  * macosx.h: MacOS X plugin for vlc
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: macosx.h,v 1.6 2002/04/17 23:03:35 massiot Exp $
+ * $Id: macosx.h,v 1.9 2002/05/12 01:39:36 massiot Exp $
  *
  * Authors: Colin Delacroix <colin@zoy.org>
  *          Eugenio Jarosiewicz <ej0@cise.ufl.edu>
@@ -37,6 +37,12 @@ typedef struct intf_sys_s
 {
     NSPort *o_port;
     NSAutoreleasePool *o_pool;
+
+    boolean_t b_mute;
+    int i_saved_volume;
+    
+    int i_part;
+    boolean_t b_disabled_menus;
 } intf_sys_t;
 
 /*****************************************************************************
@@ -52,12 +58,11 @@ typedef struct vout_sys_s
     boolean_t b_mouse_moved;
     boolean_t b_mouse_pointer_visible;
     mtime_t i_time_mouse_last_moved;
-
+    
     CodecType i_codec;
     CGrafPtr p_qdport;
     ImageSequence i_seq;
     MatrixRecordPtr p_matrix;
-    Rect display_rect;
     DecompressorComponent img_dc;
     ImageDescriptionHandle h_img_descr;
 } vout_sys_t;
