@@ -2,9 +2,10 @@
  * spu_decoder.c : spu decoder thread
  *****************************************************************************
  * Copyright (C) 2000-2001 VideoLAN
- * $Id: spu_decoder.c,v 1.15 2002/04/18 12:51:59 sam Exp $
+ * $Id: spu_decoder.c,v 1.23 2002/05/19 15:50:02 stef Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
+ *          Rudolf Cornelissen <rag.cornelissen@inter.nl.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -121,6 +122,8 @@ static int decoder_Run( decoder_config_t * p_config )
     /*
      * Initialize the thread properties
      */
+    p_spudec->p_vout = NULL;
+
     p_spudec->p_config = p_config;
 
     p_spudec->p_fifo = p_config->p_decoder_fifo;
@@ -150,16 +153,19 @@ static int decoder_Run( decoder_config_t * p_config )
         DecoderError( p_spudec->p_fifo );
     }
 
-    /* End of thread */
-    EndThread( p_spudec );
-
-    if( p_spudec->p_fifo->b_error )
     {
-        return( -1 );
+        boolean_t b_error = p_spudec->p_fifo->b_error;
+
+        /* End of thread */
+        EndThread( p_spudec );
+
+        if( b_error )
+        {
+            return( -1 );
+        }
     }
    
     return( 0 );
-
 }
 
 /* following functions are local */
@@ -207,6 +213,25 @@ static int InitThread( spudec_thread_t *p_spudec )
  *****************************************************************************/
 static void EndThread( spudec_thread_t *p_spudec )
 {
+    if( p_spudec->p_vout != NULL 
+     && p_spudec->p_vout->p_subpicture != NULL )
+    {
+        subpicture_t *  p_subpic;
+        int             i_subpic;
+    
+        for( i_subpic = 0; i_subpic < VOUT_MAX_SUBPICTURES; i_subpic++ )
+        {
+            p_subpic = &p_spudec->p_vout->p_subpicture[i_subpic];
+
+            if( p_subpic != NULL &&
+              ( ( p_subpic->i_status == RESERVED_SUBPICTURE )
+             || ( p_subpic->i_status == READY_SUBPICTURE ) ) )
+            {
+                vout_DestroySubPicture( p_spudec->p_vout, p_subpic );
+            }
+        }
+    }
+    
     free( p_spudec );
 }
 
@@ -370,8 +395,6 @@ static int ParseControlSequences( spudec_thread_t *p_spudec,
     u8  i_command;
     int i_date;
 
-    /* Dummy stuff */
-    u8 *pi_color;
     int i;
 
     /* XXX: temporary variables */
@@ -426,16 +449,21 @@ static int ParseControlSequences( spudec_thread_t *p_spudec,
                 case SPU_CMD_SET_PALETTE:
  
                     /* 03xxxx (palette) */
-                    if( p_spudec->p_config->p_demux_data )
+                    if( p_spudec->p_config->p_demux_data &&
+                         *(int*)p_spudec->p_config->p_demux_data == 0xBeeF )
                     {
+                        u32 i_color;
+
                         p_spu->p_sys->b_palette = 1;
                         for( i = 0; i < 4 ; i++ )
                         {
-                            pi_color = (u8*)p_spudec->p_config->p_demux_data
-                                    + 4 * GetBits( &p_spudec->bit_stream, 4 );
-                            p_spu->p_sys->pi_yuv[3-i][0] = pi_color[2];
-                            p_spu->p_sys->pi_yuv[3-i][1] = pi_color[0];
-                            p_spu->p_sys->pi_yuv[3-i][2] = pi_color[1];
+                            i_color = ((u32*)((char*)p_spudec->p_config->
+                                        p_demux_data + sizeof(int)))[
+                                          GetBits(&p_spudec->bit_stream, 4) ];
+
+                            p_spu->p_sys->pi_yuv[3-i][0] = (i_color>>16) & 0xff;
+                            p_spu->p_sys->pi_yuv[3-i][1] = (i_color>>0) & 0xff;
+                            p_spu->p_sys->pi_yuv[3-i][2] = (i_color>>8) & 0xff;
                         }
                     }
                     else
@@ -819,6 +847,7 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
 
     int i_x, i_y;
     int i_len, i_color;
+    u8  i_cnt;
 
     /* RGB-specific */
     int i_xscale, i_yscale, i_width, i_height, i_ytmp, i_yreal, i_ynext;
@@ -830,13 +859,13 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
     case FOURCC_IYUV:
     case FOURCC_YV12:
 
-    p_dest = p_pic->p->p_pixels + p_spu->i_x + p_spu->i_width
-              + p_vout->output.i_width * ( p_spu->i_y + p_spu->i_height );
+    p_dest = p_pic->Y_PIXELS + p_spu->i_x + p_spu->i_width
+              + p_pic->Y_PITCH * ( p_spu->i_y + p_spu->i_height );
 
     /* Draw until we reach the bottom of the subtitle */
-    for( i_y = p_spu->i_height * p_vout->output.i_width ;
+    for( i_y = p_spu->i_height * p_pic->Y_PITCH ;
          i_y ;
-         i_y -= p_vout->output.i_width )
+         i_y -= p_pic->Y_PITCH )
     {
         /* Draw until we reach the end of the line */
         for( i_x = p_spu->i_width ; i_x ; )
@@ -1096,6 +1125,78 @@ static void RenderSPU( const vout_thread_t *p_vout, picture_t *p_pic,
 
     break;
 
+    /* NVidia overlay, no scaling */
+    case FOURCC_YUY2:
+
+    p_dest = p_pic->p->p_pixels +
+              (p_spu->i_x + p_spu->i_width +
+               p_vout->output.i_width * ( p_spu->i_y + p_spu->i_height )) * 2;
+    /* Draw until we reach the bottom of the subtitle */
+    for( i_y = p_spu->i_height * p_vout->output.i_width;
+         i_y ;
+         i_y -= p_vout->output.i_width )
+    {
+        /* Draw until we reach the end of the line */
+        for( i_x = p_spu->i_width ; i_x ; )
+        {
+            /* Get the RLE part, then draw the line */
+            i_color = *p_source & 0x3;
+
+            switch( p_spu->p_sys->pi_alpha[ i_color ] )
+            {
+            case 0x00:
+                i_x -= *p_source++ >> 2;
+                break;
+
+            case 0x0f:
+                i_len = *p_source++ >> 2;
+                for( i_cnt = 0; i_cnt < i_len; i_cnt++ )
+                {
+                    /* draw a pixel */
+                    /* Y */
+                    memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2,
+                            p_spu->p_sys->pi_yuv[i_color][0], 1);
+
+                    if (!(i_cnt & 0x01))
+                    {
+                        /* U and V */
+                        memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2 + 1,
+                                0x80, 1);
+                        memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2 + 3,
+                                0x80, 1);
+                    }
+                }
+                i_x -= i_len;
+                break;
+
+            default:
+                /* FIXME: we should do transparency */
+                i_len = *p_source++ >> 2;
+                for( i_cnt = 0; i_cnt < i_len; i_cnt++ )
+                {
+                    /* draw a pixel */
+                    /* Y */
+                    memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2,
+                            p_spu->p_sys->pi_yuv[i_color][0], 1);
+
+                    if (!(i_cnt & 0x01))
+                    {
+                        /* U and V */
+                        memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2 + 1,
+                                0x80, 1);
+                        memset( p_dest - i_x * 2 - i_y * 2 + i_cnt * 2 + 3,
+                                0x80, 1);
+                    }
+                }
+                i_x -= i_len;
+                break;
+            }
+        }
+    }
+
+    break;
+
+
     default:
         intf_ErrMsg( "vout error: unknown chroma, can't render SPU" );
         break;
