@@ -2,7 +2,7 @@
  * xvideo.c : Xvideo plugin for vlc
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: xvideo.c,v 1.9 2002/03/25 19:16:20 gbazin Exp $
+ * $Id: xvideo.c,v 1.12 2002/05/13 17:58:08 sam Exp $
  *
  * Authors: Shane Harper <shanegh@optusnet.com.au>
  *          Vincent Seguin <seguin@via.ecp.fr>
@@ -37,34 +37,40 @@
 /*****************************************************************************
  * Building configuration tree
  *****************************************************************************/
-#define ADAPTOR_TEXT "XVideo adaptor number"
-#define ADAPTOR_LONGTEXT "If you graphics card provides several adaptors, " \
-                         "this option allows you to choose which one will " \
-                         "be used (you shouldn't have to change this)"
+#define ADAPTOR_TEXT N_("XVideo adaptor number")
+#define ADAPTOR_LONGTEXT N_( \
+    "If you graphics card provides several adaptors, this option allows you " \
+    "to choose which one will be used (you shouldn't have to change this).")
 
-#define ALT_FS_TEXT "Alternate fullscreen method"
-#define ALT_FS_LONGTEXT "There are two ways to make a fullscreen window, " \
-                        "unfortunately each one has its drawbacks.\n" \
-                        "1) Let the window manager handle your fullscreen " \
-                        "window (default). But things like taskbars will " \
-                        "likely show on top of the video\n" \
-                        "2) Completly bypass the window manager, but then " \
-                        "nothing will be able to show on top of the video"
+#define ALT_FS_TEXT N_("alternate fullscreen method")
+#define ALT_FS_LONGTEXT N_( \
+    "There are two ways to make a fullscreen window, unfortunately each one " \
+    "has its drawbacks.\n" \
+    "1) Let the window manager handle your fullscreen window (default). But " \
+    "things like taskbars will likely show on top of the video.\n" \
+    "2) Completly bypass the window manager, but then nothing will be able " \
+    "to show on top of the video.")
 
-#define DISPLAY_TEXT "X11 display name"
-#define DISPLAY_LONGTEXT "Specify the X11 hardware display you want to use.\n"\
-                         "By default vlc will use the value of the DISPLAY " \
-                         "environment variable."
+#define DISPLAY_TEXT N_("X11 display name")
+#define DISPLAY_LONGTEXT N_( \
+    "Specify the X11 hardware display you want to use.\nBy default vlc will " \
+    "use the value of the DISPLAY environment variable.")
+
+#define CHROMA_TEXT N_("XVimage chroma format")
+#define CHROMA_LONGTEXT N_( \
+    "Force the XVideo renderer to use a specific chroma format instead of " \
+    "trying to improve performances by using the most efficient one.")
 
 MODULE_CONFIG_START
-ADD_CATEGORY_HINT( "Miscellaneous", NULL )
-ADD_STRING  ( "xvideo_display", NULL, NULL, DISPLAY_TEXT, DISPLAY_LONGTEXT )
-ADD_INTEGER ( "xvideo_adaptor", -1, NULL, ADAPTOR_TEXT, ADAPTOR_LONGTEXT )
-ADD_BOOL    ( "xvideo_altfullscreen", NULL, ALT_FS_TEXT, ALT_FS_LONGTEXT )
+ADD_CATEGORY_HINT( N_("Miscellaneous"), NULL )
+ADD_STRING  ( "xvideo-display", NULL, NULL, DISPLAY_TEXT, DISPLAY_LONGTEXT )
+ADD_INTEGER ( "xvideo-adaptor", -1, NULL, ADAPTOR_TEXT, ADAPTOR_LONGTEXT )
+ADD_BOOL    ( "xvideo-altfullscreen", NULL, ALT_FS_TEXT, ALT_FS_LONGTEXT )
+ADD_STRING  ( "xvideo-chroma", NULL, NULL, CHROMA_TEXT, CHROMA_LONGTEXT )
 MODULE_CONFIG_STOP
 
 MODULE_INIT_START
-    SET_DESCRIPTION( "XVideo extension module" )
+    SET_DESCRIPTION( _("XVideo extension module") )
     ADD_CAPABILITY( VOUT, 150 )
     ADD_SHORTCUT( "xvideo" )
 MODULE_INIT_STOP
