@@ -2,7 +2,7 @@
  * mpeg_system.c: TS, PS and PES management
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: mpeg_system.c,v 1.90 2002/04/17 17:00:58 jobi Exp $
+ * $Id: mpeg_system.c,v 1.96 2002/05/18 17:47:47 sam Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Michel Lespinasse <walken@via.ecp.fr>
@@ -39,13 +39,6 @@
 #include "input_ext-dec.h"
 #include "input_ext-plugins.h"
 
-/*****************************************************************************
- * Local prototypes
- *****************************************************************************/
-
-static void input_DecodePAT( input_thread_t *, es_descriptor_t *);
-static void input_DecodePMT( input_thread_t *, es_descriptor_t *);
-
 /*
  * PES Packet management
  */
@@ -58,10 +51,8 @@ static void input_DecodePMT( input_thread_t *, es_descriptor_t *);
  * It also solves some alignment problems on non-IA-32, non-PPC processors.
  * This is a variation on the theme of input_ext-dec.h:GetChunk().
  *****************************************************************************/
-static __inline__ size_t MoveChunk( byte_t * p_dest,
-                                    data_packet_t ** pp_data_src,
-                                    byte_t ** pp_src,
-                                    size_t i_buf_len )
+static inline size_t MoveChunk( byte_t * p_dest, data_packet_t ** pp_data_src,
+                                byte_t ** pp_src, size_t i_buf_len )
 {
     ptrdiff_t           i_available;
 
@@ -679,6 +670,7 @@ ssize_t input_ReadPS( input_thread_t * p_input, data_packet_t ** pp_data )
         {
             p_input->p_current_data++;
             PEEK( 4 );
+            if( p_input->b_die ) return( -1 );
         }
         /* Packet found. */
     }
@@ -811,11 +803,11 @@ es_descriptor_t * input_ParsePS( input_thread_t * p_input,
                         p_es->i_cat = AUDIO_ES;
 #ifdef AUTO_SPAWN
                         if( !p_input->stream.b_seekable )
-                        if( config_GetIntVariable( "input_channel" )
+                        if( config_GetIntVariable( "audio-channel" )
                                 == (p_es->i_id & 0x1F) ||
-                            ( config_GetIntVariable( "input_channel" ) < 0
+                            ( config_GetIntVariable( "audio-channel" ) < 0
                               && !(p_es->i_id & 0x1F) ) )
-                        switch( config_GetIntVariable( "input_audio" ) )
+                        switch( config_GetIntVariable( "audio-type" ) )
                         {
                         case -1:
                         case REQUESTED_MPEG:
@@ -831,11 +823,11 @@ es_descriptor_t * input_ParsePS( input_thread_t * p_input,
                         p_es->i_cat = AUDIO_ES;
 #ifdef AUTO_SPAWN
                         if( !p_input->stream.b_seekable )
-                        if( config_GetIntVariable( "input_channel" )
+                        if( config_GetIntVariable( "audio-channel" )
                                 == ((p_es->i_id & 0xF00) >> 8) ||
-                            ( config_GetIntVariable( "input_channel" ) < 0
+                            ( config_GetIntVariable( "audio-channel" ) < 0
                               && !((p_es->i_id & 0xF00) >> 8)) )
-                        switch( config_GetIntVariable( "input_audio" ) )
+                        switch( config_GetIntVariable( "audio-type" ) )
                         {
                         case -1:
                         case REQUESTED_AC3:
@@ -849,7 +841,7 @@ es_descriptor_t * input_ParsePS( input_thread_t * p_input,
                         p_es->i_type = DVD_SPU_ES;
                         p_es->i_cat = SPU_ES;
 #ifdef AUTO_SPAWN
-                        if( config_GetIntVariable( "input_subtitle" )
+                        if( config_GetIntVariable( "spu-channel" )
                                 == ((p_es->i_id & 0x1F00) >> 8) )
                         {
                             if( !p_input->stream.b_seekable )
@@ -1087,7 +1079,8 @@ ssize_t input_ReadTS( input_thread_t * p_input, data_packet_t ** pp_data )
 /*****************************************************************************
  * input_DemuxTS: first step of demultiplexing: the TS header
  *****************************************************************************/
-void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
+void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data,
+                        psi_callback_t pf_psi_callback )
 {
     u16                 i_pid;
     int                 i_dummy;
@@ -1097,6 +1090,7 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
     boolean_t           b_trash = 0;             /* Is the packet unuseful ? */
     boolean_t           b_lost = 0;             /* Was there a packet loss ? */
     boolean_t           b_psi = 0;                        /* Is this a PSI ? */
+    boolean_t           b_pcr = 0;                   /* Does it have a PCR ? */
     es_descriptor_t *   p_es = NULL;
     es_ts_data_t *      p_es_demux = NULL;
     pgrm_ts_data_t *    p_pgrm_demux = NULL;
@@ -1110,7 +1104,17 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
 
     /* Find out the elementary stream. */
     vlc_mutex_lock( &p_input->stream.stream_lock );
-        
+    
+    for( i_dummy = 0; i_dummy < p_input->stream.i_pgrm_number; i_dummy ++ )
+    {
+        if( (( pgrm_ts_data_t * ) p_input->stream.pp_programs[i_dummy]->
+                    p_demux_data)->i_pcr_pid == i_pid )
+        {
+            b_pcr = 1;
+            break;
+        }
+    }
+            
     p_es= input_FindES( p_input, i_pid );
     
     if( (p_es != NULL) && (p_es->p_demux_data != NULL) )
@@ -1145,9 +1149,8 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
     /* Don't change the order of the tests : if b_psi then p_pgrm_demux 
      * may still be null. Who said it was ugly ?
      * I have written worse. --Meuuh */
-    if( ( p_es != NULL ) && 
-        ((p_es->p_decoder_fifo != NULL) || b_psi 
-                                   || (p_pgrm_demux->i_pcr_pid == i_pid) ) )
+    if( ( p_es  ) && 
+        ((p_es->p_decoder_fifo != NULL) || b_psi || b_pcr ) )
     {
         p_es->c_packets++;
 
@@ -1206,29 +1209,6 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
                         p_es_demux->i_continuity_counter = (p[3] & 0x0f) - 1;
                     }
     
-                    /* If this is a PCR_PID, and this TS packet contains a
-                     * PCR, we pass it along to the PCR decoder. */
-
-                    if( !b_psi && (p_pgrm_demux->i_pcr_pid == i_pid)
-                        && (p[5] & 0x10) )
-                    {
-                        /* There should be a PCR field in the packet, check
-                         * if the adaptation field is long enough to carry
-                         * it. */
-                        if( p[4] >= 7 )
-                        {
-                            /* Read the PCR. */
-                            mtime_t     pcr_time;
-                            pcr_time = ( (mtime_t)p[6] << 25 ) |
-                                       ( (mtime_t)p[7] << 17 ) |
-                                       ( (mtime_t)p[8] << 9 ) |
-                                       ( (mtime_t)p[9] << 1 ) |
-                                       ( (mtime_t)p[10] >> 7 );
-                            /* Call the pace control. */
-                            input_ClockManageRef( p_input, p_es->p_pgrm,
-                                                  pcr_time );
-                        }
-                    } /* PCR ? */
                 } /* valid TS adaptation field ? */
             } /* length > 0 */
         } /* has adaptation field */
@@ -1284,6 +1264,30 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
         } /* continuity */
     } /* if selected or PCR */
     
+    /* Handle PCR */
+    if( b_pcr && b_adaptation && (p[5] & 0x10) && p[4]>=7 )
+    {
+        /* Read the PCR. */
+        mtime_t     pcr_time;
+        pcr_time = ( (mtime_t)p[6] << 25 ) |
+                   ( (mtime_t)p[7] << 17 ) |
+                   ( (mtime_t)p[8] << 9 ) |
+                   ( (mtime_t)p[9] << 1 ) |
+                   ( (mtime_t)p[10] >> 7 );
+        /* Call the pace control. */
+        for( i_dummy = 0; i_dummy < p_input->stream.i_pgrm_number; 
+                                i_dummy ++ )
+        {
+            if( ( ( pgrm_ts_data_t * ) p_input->stream.pp_programs[i_dummy]->
+                        p_demux_data )->i_pcr_pid == i_pid )
+            {
+                input_ClockManageRef( p_input,
+                    p_input->stream.pp_programs[i_dummy], pcr_time );
+            }
+        }
+
+    }
+    
     /* Trash the packet if it has no payload or if it isn't selected */
     if( b_trash )
     {
@@ -1295,9 +1299,7 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
         if( b_psi )
         {
             /* The payload contains PSI tables */
-            input_DemuxPSI( p_input, p_data, p_es,
-                            b_unit_start, b_lost );
-
+            (* pf_psi_callback) ( p_input, p_data, p_es, b_unit_start );
         }
         else
         {
@@ -1310,429 +1312,3 @@ void input_DemuxTS( input_thread_t * p_input, data_packet_t * p_data )
 #undef p
 
 }
-
-/*
- * PSI demultiplexing and decoding
- */
-
-/*****************************************************************************
- * DemuxPSI : makes up complete PSI data
- *****************************************************************************/
-void input_DemuxPSI( input_thread_t * p_input, data_packet_t * p_data, 
-        es_descriptor_t * p_es, boolean_t b_unit_start, boolean_t b_lost )
-{
-    es_ts_data_t  * p_demux_data;
-    
-    p_demux_data = (es_ts_data_t *)p_es->p_demux_data;
-
-#define p_psi (p_demux_data->p_psi_section)
-#define p (p_data->p_payload_start)
-
-    if( b_unit_start )
-    {
-        /* unit_start set to 1 -> presence of a pointer field
-         * (see ISO/IEC 13818 (2.4.4.2) which should be set to 0x00 */
-        if( (u8)p[0] != 0x00 )
-        {
-            intf_WarnMsg( 2, "input: non zero pointer field found, "
-                             "trying to continue" );
-            p+=(u8)p[0];
-        }
-        else
-        {
-            p++;
-        }
-
-        /* This is the begining of a new section */
-
-        if( ((u8)(p[1]) & 0xc0) != 0x80 ) 
-        {
-            intf_WarnMsg( 2, "input: invalid PSI packet" );
-            p_psi->b_trash = 1;
-        }
-        else 
-        {
-            p_psi->i_section_length = ((p[1] & 0xF) << 8) | p[2];
-            p_psi->b_section_complete = 0;
-            p_psi->i_read_in_section = 0;
-            p_psi->i_section_number = (u8)p[6];
-
-            if( p_psi->b_is_complete || p_psi->i_section_number == 0 )
-            {
-                /* This is a new PSI packet */
-                p_psi->b_is_complete = 0;
-                p_psi->b_trash = 0;
-                p_psi->i_version_number = ( p[5] >> 1 ) & 0x1f;
-                p_psi->i_last_section_number = (u8)p[7];
-
-                /* We'll write at the begining of the buffer */
-                p_psi->p_current = p_psi->buffer;
-            }
-            else
-            {
-                if( p_psi->b_section_complete )
-                {
-                    /* New Section of an already started PSI */
-                    p_psi->b_section_complete = 0;
-                    
-                    if( p_psi->i_version_number != (( p[5] >> 1 ) & 0x1f) )
-                    {
-                        intf_WarnMsg( 2, "input: PSI version differs "
-                                         "inside same PAT" );
-                        p_psi->b_trash = 1;
-                    }
-                    if( p_psi->i_section_number + 1 != (u8)p[6] )
-                    {
-                        intf_WarnMsg( 2, "input: PSI Section discontinuity, "
-                                         "packet lost ?" );
-                        p_psi->b_trash = 1;
-                    }
-                    else
-                        p_psi->i_section_number++;
-                }
-                else
-                {
-                    intf_WarnMsg( 2, "input: got unexpected new PSI section" );
-                    p_psi->b_trash = 1;
-                }
-            }
-        }
-    } /* b_unit_start */
-    
-    if( !p_psi->b_trash )
-    {
-        /* read */
-        if( (p_data->p_payload_end - p) >=
-            ( p_psi->i_section_length - p_psi->i_read_in_section ) )
-        {
-            /* The end of the section is in this TS packet */
-            memcpy( p_psi->p_current, p, 
-            (p_psi->i_section_length - p_psi->i_read_in_section) );
-    
-            p_psi->b_section_complete = 1;
-            p_psi->p_current += 
-                (p_psi->i_section_length - p_psi->i_read_in_section);
-                        
-            if( p_psi->i_section_number == p_psi->i_last_section_number )
-            {
-                /* This was the last section of PSI */
-                p_psi->b_is_complete = 1;
-
-                switch( p_demux_data->i_psi_type)
-                {
-                case PSI_IS_PAT:
-                    input_DecodePAT( p_input, p_es );
-                    break;
-                case PSI_IS_PMT:
-                    input_DecodePMT( p_input, p_es );
-                    break;
-                default:
-                    intf_WarnMsg(2, "Received unknown PSI in DemuxPSI");
-                }
-            }
-        }
-        else
-        {
-            memcpy( p_psi->buffer, p, p_data->p_payload_end - p );
-            p_psi->i_read_in_section += p_data->p_payload_end - p;
-
-            p_psi->p_current += p_data->p_payload_end - p;
-        }
-    }
-
-#undef p_psi    
-#undef p
-   
-    input_DeletePacket( p_input->p_method_data, p_data );
-    
-    return ;
-}
-
-/*****************************************************************************
- * DecodePAT : Decodes Programm association table and deal with it
- *****************************************************************************/
-static void input_DecodePAT( input_thread_t * p_input, es_descriptor_t * p_es )
-{
-    stream_ts_data_t  * p_stream_data;
-    es_ts_data_t      * p_demux_data;
-
-    pgrm_descriptor_t * p_pgrm;
-    es_descriptor_t   * p_current_es;
-    byte_t            * p_current_data;           
-
-    int                 i_section_length, i_program_id, i_pmt_pid;
-    int                 i_loop, i_current_section;
-
-    boolean_t           b_changed = 0;
-
-    p_demux_data = (es_ts_data_t *)p_es->p_demux_data;
-    p_stream_data = (stream_ts_data_t *)p_input->stream.p_demux_data;
-    
-#define p_psi (p_demux_data->p_psi_section)
-
-    /* Not so fast, Mike ! If the PAT version has changed, we first check
-     * that its content has really changed before doing anything */
-    if( p_stream_data->i_pat_version != p_psi->i_version_number )
-    {
-        int i_programs = p_input->stream.i_pgrm_number;
-
-        p_current_data = p_psi->buffer;
-
-        do
-        {
-            i_section_length = ((u32)(p_current_data[1] & 0xF) << 8) |
-                                 p_current_data[2];
-            i_current_section = (u8)p_current_data[6];
-    
-            for( i_loop = 0;
-                 ( i_loop < (i_section_length - 9) / 4 ) && !b_changed;
-                 i_loop++ )
-            {
-                i_program_id = ( (u32)*(p_current_data + i_loop * 4 + 8) << 8 )
-                                 | *(p_current_data + i_loop * 4 + 9);
-                i_pmt_pid = ( ((u32)*(p_current_data + i_loop * 4 + 10) & 0x1F)
-                                    << 8 )
-                               | *(p_current_data + i_loop * 4 + 11);
-
-                if( i_program_id )
-                {
-                    if( (p_pgrm = input_FindProgram( p_input, i_program_id ))
-                        && (p_current_es = input_FindES( p_input, i_pmt_pid ))
-                        && p_current_es->p_pgrm == p_pgrm
-                        && p_current_es->i_id == i_pmt_pid
-                        && ((es_ts_data_t *)p_current_es->p_demux_data)->b_psi
-                        && ((es_ts_data_t *)p_current_es->p_demux_data)
-                            ->i_psi_type == PSI_IS_PMT )
-                    {
-                        i_programs--;
-                    }
-                    else
-                    {
-                        b_changed = 1;
-                    }
-                }
-            }
-            
-            p_current_data += 3 + i_section_length;
-
-        } while( ( i_current_section < p_psi->i_last_section_number )
-                  && !b_changed );
-
-        /* If we didn't find the expected amount of programs, the PAT has
-         * changed. Otherwise, it only changed if b_changed is already != 0 */
-        b_changed = b_changed || i_programs;
-    }
-
-    if( b_changed )
-    {
-        /* PAT has changed. We are going to delete all programs and 
-         * create new ones. We chose not to only change what was needed
-         * as a PAT change may mean the stream is radically changing and
-         * this is a secure method to avoid crashes */
-        es_ts_data_t      * p_es_demux;
-        pgrm_ts_data_t    * p_pgrm_demux;
-        
-        p_current_data = p_psi->buffer;
-
-        /* Delete all programs */
-        while( p_input->stream.i_pgrm_number )
-        {
-            input_DelProgram( p_input, p_input->stream.pp_programs[0] );
-        }
-        
-        do
-        {
-            i_section_length = ((u32)(p_current_data[1] & 0xF) << 8) |
-                                 p_current_data[2];
-            i_current_section = (u8)p_current_data[6];
-    
-            for( i_loop = 0; i_loop < (i_section_length - 9) / 4 ; i_loop++ )
-            {
-                i_program_id = ( (u32)*(p_current_data + i_loop * 4 + 8) << 8 )
-                                 | *(p_current_data + i_loop * 4 + 9);
-                i_pmt_pid = ( ((u32)*(p_current_data + i_loop * 4 + 10) & 0x1F)
-                                    << 8 )
-                               | *(p_current_data + i_loop * 4 + 11);
-    
-                /* If program = 0, we're having info about NIT not PMT */
-                if( i_program_id )
-                {
-                    /* Add this program */
-                    p_pgrm = input_AddProgram( p_input, i_program_id, 
-                                               sizeof( pgrm_ts_data_t ) );
-                   
-                    /* whatis the PID of the PMT of this program */
-                    p_pgrm_demux = (pgrm_ts_data_t *)p_pgrm->p_demux_data;
-                    p_pgrm_demux->i_pmt_version = PMT_UNINITIALIZED;
-    
-                    /* Add the PMT ES to this program */
-                    p_current_es = input_AddES( p_input, p_pgrm,(u16)i_pmt_pid,
-                                        sizeof( es_ts_data_t) );
-                    p_es_demux = (es_ts_data_t *)p_current_es->p_demux_data;
-                    p_es_demux->b_psi = 1;
-                    p_es_demux->i_psi_type = PSI_IS_PMT;
-                    
-                    p_es_demux->p_psi_section = 
-                                            malloc( sizeof( psi_section_t ) );
-                    p_es_demux->p_psi_section->b_is_complete = 0;
-                }
-            }
-            
-            p_current_data += 3 + i_section_length;
-
-        } while( i_current_section < p_psi->i_last_section_number );
-
-        /* Go to the beginning of the next section */
-        p_stream_data->i_pat_version = p_psi->i_version_number;
-
-    }
-#undef p_psi
-
-}
-
-/*****************************************************************************
- * DecodePMT : decode a given Program Stream Map
- * ***************************************************************************
- * When the PMT changes, it may mean a deep change in the stream, and it is
- * careful to delete the ES and add them again. If the PMT doesn't change,
- * there no need to do anything.
- *****************************************************************************/
-static void input_DecodePMT( input_thread_t * p_input, es_descriptor_t * p_es )
-{
-
-    pgrm_ts_data_t            * p_pgrm_data;
-    es_ts_data_t              * p_demux_data;
-
-    p_demux_data = (es_ts_data_t *)p_es->p_demux_data;
-    p_pgrm_data = (pgrm_ts_data_t *)p_es->p_pgrm->p_demux_data;
-    
-#define p_psi (p_demux_data->p_psi_section)
-
-    if( p_psi->i_version_number != p_pgrm_data->i_pmt_version ) 
-    {
-        es_descriptor_t   * p_new_es;  
-        es_ts_data_t      * p_es_demux;
-        byte_t            * p_current_data, * p_current_section;
-        int                 i_section_length,i_current_section;
-        int                 i_prog_info_length, i_loop;
-        int                 i_es_info_length, i_pid, i_stream_type;
-        
-        p_current_section = p_psi->buffer;
-        p_current_data = p_psi->buffer;
-
-        p_pgrm_data->i_pcr_pid = ( ((u32)*(p_current_section + 8) & 0x1F) << 8 ) |
-                                    *(p_current_section + 9);
-
-
-        /* Lock stream information */
-        vlc_mutex_lock( &p_input->stream.stream_lock );
-
-        /* Delete all ES in this program  except the PSI. We start from the
-         * end because i_es_number gets decremented after each deletion. */
-        for( i_loop = p_es->p_pgrm->i_es_number ; i_loop ; )
-        {
-            i_loop--;
-            p_es_demux = (es_ts_data_t *)
-                         p_es->p_pgrm->pp_es[i_loop]->p_demux_data;
-            if ( ! p_es_demux->b_psi )
-            {
-                input_DelES( p_input, p_es->p_pgrm->pp_es[i_loop] );
-            }
-        }
-
-        /* Then add what we received in this PMT */
-        do
-        {
-            i_section_length = ( ((u32)*(p_current_data + 1) & 0xF) << 8 ) |
-                                  *(p_current_data + 2);
-            i_current_section = (u8)p_current_data[6];
-            i_prog_info_length = ( ((u32)*(p_current_data + 10) & 0xF) << 8 ) |
-                                    *(p_current_data + 11);
-
-            /* For the moment we ignore program descriptors */
-            p_current_data += 12 + i_prog_info_length;
-    
-            /* The end of the section, before the CRC is at 
-             * p_current_section + i_section_length -1 */
-            while( p_current_data < p_current_section + i_section_length -1 )
-            {
-                i_stream_type = (int)p_current_data[0];
-                i_pid = ( ((u32)*(p_current_data + 1) & 0x1F) << 8 ) |
-                           *(p_current_data + 2);
-                i_es_info_length = ( ((u32)*(p_current_data + 3) & 0xF) << 8 ) |
-                                      *(p_current_data + 4);
-                
-                /* Add this ES to the program */
-                p_new_es = input_AddES( p_input, p_es->p_pgrm, 
-                                        (u16)i_pid, sizeof( es_ts_data_t ) );
-
-                /* Tell the decoders what kind of stream it is */
-                p_new_es->i_type = i_stream_type;
-
-                /* Tell the interface what kind of stream it is and select 
-                 * the required ones */
-                {
-                    switch( i_stream_type )
-                    {
-                        case MPEG1_VIDEO_ES:
-                        case MPEG2_VIDEO_ES:
-                            p_new_es->i_cat = VIDEO_ES;
-                            break;
-                        case MPEG1_AUDIO_ES:
-                        case MPEG2_AUDIO_ES:
-                            p_new_es->i_cat = AUDIO_ES;
-                            break;
-                        case LPCM_AUDIO_ES :
-                        case AC3_AUDIO_ES :
-                            p_new_es->i_stream_id = 0xBD;
-                            p_new_es->i_cat = AUDIO_ES;
-                            break;
-                        /* Not sure this one is fully specification-compliant */
-                        case DVD_SPU_ES :
-                            p_new_es->i_stream_id = 0xBD;
-                            p_new_es->i_cat = SPU_ES;
-                            break;
-                        default :
-                            p_new_es->i_cat = UNKNOWN_ES;
-                            break;
-                    }
-                }
-                
-                p_current_data += 5 + i_es_info_length;
-            }
-
-            /* Go to the beginning of the next section*/
-            p_current_data += 3 + i_section_length;
-           
-            p_current_section++;
-            
-        } while( i_current_section < p_psi->i_last_section_number );
-
-        p_pgrm_data->i_pmt_version = p_psi->i_version_number;
-
-        /* if no program is selected :*/
-        if( !p_input->stream.p_selected_program )
-        {
-            pgrm_descriptor_t *     p_pgrm_to_select;
-            u16 i_id = (u16)config_GetIntVariable( "input_program" );
-
-            if( i_id != 0 ) /* if user specified a program */
-            {
-                p_pgrm_to_select = input_FindProgram( p_input, i_id );
-
-                if( p_pgrm_to_select || p_pgrm_to_select == p_es->p_pgrm )
-                    p_input->pf_set_program( p_input, p_pgrm_to_select );
-            }
-            else
-                    p_input->pf_set_program( p_input, p_es->p_pgrm );
-        }
-        
-        /* inform interface that stream has changed */
-        p_input->stream.b_changed = 1;
-        /*  Remove lock */
-        vlc_mutex_unlock( &p_input->stream.stream_lock );
-    }
-    
-#undef p_psi
-}
-
