@@ -2,7 +2,7 @@
  * configuration.c management of the modules configuration
  *****************************************************************************
  * Copyright (C) 2001 VideoLAN
- * $Id: configuration.c,v 1.14 2002/04/17 11:43:31 sam Exp $
+ * $Id: configuration.c,v 1.25 2002/05/18 17:53:11 massiot Exp $
  *
  * Authors: Gildas Bazin <gbazin@netcourrier.com>
  *
@@ -26,7 +26,7 @@
 #include <stdio.h>                                              /* sprintf() */
 #include <stdlib.h>                                      /* free(), strtol() */
 #include <string.h>                                              /* strdup() */
-#include <errno.h>					           /* errno */
+#include <errno.h>                                                  /* errno */
 
 #ifdef HAVE_UNISTD_H
 #    include <unistd.h>                                          /* getuid() */
@@ -77,12 +77,40 @@ int config_GetIntVariable( const char *psz_name )
     return p_config->i_value;
 }
 
+/*****************************************************************************
+ * config_GetFloatVariable: get the value of a float variable
+ *****************************************************************************
+ * This function is used to get the value of variables which are internally
+ * represented by a float (MODULE_CONFIG_ITEM_FLOAT).
+ *****************************************************************************/
+float config_GetFloatVariable( const char *psz_name )
+{
+    module_config_t *p_config;
+
+    p_config = config_FindConfig( psz_name );
+
+    /* sanity checks */
+    if( !p_config )
+    {
+        intf_ErrMsg( "config error: option %s doesn't exist", psz_name );
+        return -1;
+    }
+    if( p_config->i_type != MODULE_CONFIG_ITEM_FLOAT )
+    {
+        intf_ErrMsg( "config error: option %s doesn't refer to a float",
+                     psz_name );
+        return -1;
+    }
+
+    return p_config->f_value;
+}
+
 /*****************************************************************************
  * config_GetPszVariable: get the string value of a string variable
  *****************************************************************************
  * This function is used to get the value of variables which are internally
  * represented by a string (MODULE_CONFIG_ITEM_STRING, MODULE_CONFIG_ITEM_FILE,
- * and MODULE_CONFIG_ITEM_PLUGIN).
+ * and MODULE_CONFIG_ITEM_MODULE).
  *
  * Important note: remember to free() the returned char* because it a duplicate
  *   of the actual value. It isn't safe to return a pointer to the actual value
@@ -103,7 +131,7 @@ char * config_GetPszVariable( const char *psz_name )
     }
     if( (p_config->i_type!=MODULE_CONFIG_ITEM_STRING) &&
         (p_config->i_type!=MODULE_CONFIG_ITEM_FILE) &&
-        (p_config->i_type!=MODULE_CONFIG_ITEM_PLUGIN) )
+        (p_config->i_type!=MODULE_CONFIG_ITEM_MODULE) )
     {
         intf_ErrMsg( "config error: option %s doesn't refer to a string",
                      psz_name );
@@ -123,7 +151,7 @@ char * config_GetPszVariable( const char *psz_name )
  *****************************************************************************
  * This function is used to set the value of variables which are internally
  * represented by a string (MODULE_CONFIG_ITEM_STRING, MODULE_CONFIG_ITEM_FILE,
- * and MODULE_CONFIG_ITEM_PLUGIN).
+ * and MODULE_CONFIG_ITEM_MODULE).
  *****************************************************************************/
 void config_PutPszVariable( const char *psz_name, char *psz_value )
 {
@@ -139,7 +167,7 @@ void config_PutPszVariable( const char *psz_name, char *psz_value )
     }
     if( (p_config->i_type!=MODULE_CONFIG_ITEM_STRING) &&
         (p_config->i_type!=MODULE_CONFIG_ITEM_FILE) &&
-        (p_config->i_type!=MODULE_CONFIG_ITEM_PLUGIN) )
+        (p_config->i_type!=MODULE_CONFIG_ITEM_MODULE) )
     {
         intf_ErrMsg( "config error: option %s doesn't refer to a string",
                      psz_name );
@@ -156,6 +184,10 @@ void config_PutPszVariable( const char *psz_name, char *psz_value )
 
     vlc_mutex_unlock( p_config->p_lock );
 
+    if( p_config->p_callback )
+    {
+        ((void(*)(void))p_config->p_callback)();
+    }
 }
 
 /*****************************************************************************
@@ -186,6 +218,44 @@ void config_PutIntVariable( const char *psz_name, int i_value )
     }
 
     p_config->i_value = i_value;
+
+    if( p_config->p_callback )
+    {
+        ((void(*)(void))p_config->p_callback)();
+    }
+}
+
+/*****************************************************************************
+ * config_PutFloatVariable: set the value of a float variable
+ *****************************************************************************
+ * This function is used to set the value of variables which are internally
+ * represented by a float (MODULE_CONFIG_ITEM_FLOAT).
+ *****************************************************************************/
+void config_PutFloatVariable( const char *psz_name, float f_value )
+{
+    module_config_t *p_config;
+
+    p_config = config_FindConfig( psz_name );
+
+    /* sanity checks */
+    if( !p_config )
+    {
+        intf_ErrMsg( "config error: option %s doesn't exist", psz_name );
+        return;
+    }
+    if( p_config->i_type != MODULE_CONFIG_ITEM_FLOAT )
+    {
+        intf_ErrMsg( "config error: option %s doesn't refer to a float",
+                     psz_name );
+        return;
+    }
+
+    p_config->f_value = f_value;
+
+    if( p_config->p_callback )
+    {
+        ((void(*)(void))p_config->p_callback)();
+    }
 }
 
 /*****************************************************************************
@@ -196,7 +266,7 @@ void config_PutIntVariable( const char *psz_name, int i_value )
 module_config_t *config_FindConfig( const char *psz_name )
 {
     module_t *p_module;
-    int i;
+    module_config_t *p_item;
 
     if( !psz_name ) return NULL;
 
@@ -204,13 +274,15 @@ module_config_t *config_FindConfig( const char *psz_name )
          p_module != NULL ;
          p_module = p_module->next )
     {
-        for( i = 0; i < p_module->i_config_lines; i++ )
+        for( p_item = p_module->p_config;
+             p_item->i_type != MODULE_CONFIG_HINT_END;
+             p_item++ )
         {
-            if( p_module->p_config[i].i_type & MODULE_CONFIG_HINT )
+            if( p_item->i_type & MODULE_CONFIG_HINT )
                 /* ignore hints */
                 continue;
-            if( !strcmp( psz_name, p_module->p_config[i].psz_name ) )
-                return &p_module->p_config[i];
+            if( !strcmp( psz_name, p_item->psz_name ) )
+                return p_item;
         }
     }
 
@@ -224,42 +296,41 @@ module_config_t *config_FindConfig( const char *psz_name )
  * this module might be unloaded from memory at any time (remember HideModule).
  * This is why we need to create an exact copy of the config data.
  *****************************************************************************/
-module_config_t *config_Duplicate( module_t *p_module )
+module_config_t *config_Duplicate( module_config_t *p_orig )
 {
-    int i;
+    int i, i_lines;
     module_config_t *p_config;
 
-    /* allocate memory */
-    p_config = (module_config_t *)malloc( sizeof(module_config_t)
-                                          * p_module->i_config_lines );
+    /* Calculate the structure length */
+    for( p_config = p_orig, i_lines = 1;
+         p_config->i_type != MODULE_CONFIG_HINT_END;
+         p_config++, i_lines++ );
+
+    /* Allocate memory */
+    p_config = (module_config_t *)malloc( sizeof(module_config_t) * i_lines );
     if( p_config == NULL )
     {
         intf_ErrMsg( "config error: can't duplicate p_config" );
         return( NULL );
     }
 
-    for( i = 0; i < p_module->i_config_lines ; i++ )
+    /* Do the duplication job */
+    for( i = 0; i < i_lines ; i++ )
     {
-        p_config[i].i_type = p_module->p_config_orig[i].i_type;
-        p_config[i].i_value = p_module->p_config_orig[i].i_value;
-        p_config[i].b_dirty = p_module->p_config_orig[i].b_dirty;
-        p_config[i].p_lock = &p_module->config_lock;
-        if( p_module->p_config_orig[i].psz_name )
-            p_config[i].psz_name =
-                strdup( p_module->p_config_orig[i].psz_name );
-        else p_config[i].psz_name = NULL;
-        if( p_module->p_config_orig[i].psz_text )
-            p_config[i].psz_text =
-                strdup( p_module->p_config_orig[i].psz_text );
-        else p_config[i].psz_text = NULL;
-        if( p_module->p_config_orig[i].psz_longtext )
-            p_config[i].psz_longtext =
-                strdup( p_module->p_config_orig[i].psz_longtext );
-        else p_config[i].psz_longtext = NULL;
-        if( p_module->p_config_orig[i].psz_value )
-            p_config[i].psz_value =
-                strdup( p_module->p_config_orig[i].psz_value );
-        else p_config[i].psz_value = NULL;
+        p_config[i].i_type = p_orig[i].i_type;
+        p_config[i].i_short = p_orig[i].i_short;
+        p_config[i].i_value = p_orig[i].i_value;
+        p_config[i].f_value = p_orig[i].f_value;
+        p_config[i].b_dirty = p_orig[i].b_dirty;
+
+        p_config[i].psz_name = p_orig[i].psz_name ?
+                                   strdup( _(p_orig[i].psz_name) ) : NULL;
+        p_config[i].psz_text = p_orig[i].psz_text ?
+                                   strdup( _(p_orig[i].psz_text) ) : NULL;
+        p_config[i].psz_longtext = p_orig[i].psz_longtext ?
+                                   strdup( _(p_orig[i].psz_longtext) ) : NULL;
+        p_config[i].psz_value = p_orig[i].psz_value ?
+                                   strdup( _(p_orig[i].psz_value) ) : NULL;
 
         /* the callback pointer is only valid when the module is loaded so this
          * value is set in ActivateModule() and reset in DeactivateModule() */
@@ -269,6 +340,37 @@ module_config_t *config_Duplicate( module_t *p_module )
     return p_config;
 }
 
+/*****************************************************************************
+ * config_SetCallbacks: sets callback functions in the duplicate p_config.
+ *****************************************************************************
+ * Unfortunatly we cannot work directly with the module's config data as
+ * this module might be unloaded from memory at any time (remember HideModule).
+ * This is why we need to duplicate callbacks each time we reload the module.
+ *****************************************************************************/
+void config_SetCallbacks( module_config_t *p_new, module_config_t *p_orig )
+{
+    while( p_new->i_type != MODULE_CONFIG_HINT_END )
+    {
+        p_new->p_callback = p_orig->p_callback;
+        p_new++;
+        p_orig++;
+    }
+}
+
+/*****************************************************************************
+ * config_UnsetCallbacks: unsets callback functions in the duplicate p_config.
+ *****************************************************************************
+ * We simply undo what we did in config_SetCallbacks.
+ *****************************************************************************/
+void config_UnsetCallbacks( module_config_t *p_new )
+{
+    while( p_new->i_type != MODULE_CONFIG_HINT_END )
+    {
+        p_new->p_callback = NULL;
+        p_new++;
+    }
+}
+
 /*****************************************************************************
  * config_LoadConfigFile: loads the configuration file.
  *****************************************************************************
@@ -278,10 +380,10 @@ module_config_t *config_Duplicate( module_t *p_module )
 int config_LoadConfigFile( const char *psz_module_name )
 {
     module_t *p_module;
+    module_config_t *p_item;
     FILE *file;
     char line[1024];
     char *p_index, *psz_option_name, *psz_option_value;
-    int i;
     char *psz_filename, *psz_homedir;
 
     /* Acquire config file lock */
@@ -306,11 +408,11 @@ int config_LoadConfigFile( const char *psz_module_name )
 
     intf_WarnMsg( 5, "config: opening config file %s", psz_filename );
 
-    file = fopen( psz_filename, "r" );
+    file = fopen( psz_filename, "rt" );
     if( !file )
     {
-        intf_WarnMsg( 1, "config: couldn't open config file %s for reading (%s)",
-                         psz_filename, strerror(errno) );
+        intf_WarnMsg( 1, "config: config file %s doesn't already exist",
+                         psz_filename );
         free( psz_filename );
         vlc_mutex_unlock( &p_main->config_lock );
         return -1;
@@ -348,7 +450,8 @@ int config_LoadConfigFile( const char *psz_module_name )
             if( line[0] == '[' ) break; /* end of section */
 
             /* ignore comments or empty lines */
-            if( (line[0] == '#') || (line[0] == (char)0) ) continue;
+            if( (line[0] == '#') || (line[0] == '\n') || (line[0] == (char)0) )
+                continue;
 
             /* get rid of line feed */
             if( line[strlen(line)-1] == '\n' )
@@ -364,47 +467,55 @@ int config_LoadConfigFile( const char *psz_module_name )
             psz_option_value = p_index + 1;
 
             /* try to match this option with one of the module's options */
-            for( i = 0; i < p_module->i_config_lines; i++ )
+            for( p_item = p_module->p_config;
+                 p_item->i_type != MODULE_CONFIG_HINT_END;
+                 p_item++ )
             {
-                if( p_module->p_config[i].i_type & MODULE_CONFIG_HINT )
+                if( p_item->i_type & MODULE_CONFIG_HINT )
                     /* ignore hints */
                     continue;
-                if( !strcmp( p_module->p_config[i].psz_name,
-                             psz_option_name ) )
+
+                if( !strcmp( p_item->psz_name, psz_option_name ) )
                 {
                     /* We found it */
-                    switch( p_module->p_config[i].i_type )
+                    switch( p_item->i_type )
                     {
                     case MODULE_CONFIG_ITEM_BOOL:
                     case MODULE_CONFIG_ITEM_INTEGER:
                         if( !*psz_option_value )
                             break;                    /* ignore empty option */
-                        p_module->p_config[i].i_value =
-                            atoi( psz_option_value);
+                        p_item->i_value = atoi( psz_option_value);
                         intf_WarnMsg( 7, "config: found <%s> option %s=%i",
-                                      p_module->psz_name,
-                                      p_module->p_config[i].psz_name,
-                                      p_module->p_config[i].i_value );
+                                         p_module->psz_name,
+                                         p_item->psz_name, p_item->i_value );
+                        break;
+
+                    case MODULE_CONFIG_ITEM_FLOAT:
+                        if( !*psz_option_value )
+                            break;                    /* ignore empty option */
+                        p_item->f_value = (float)atof( psz_option_value);
+                        intf_WarnMsg( 7, "config: found <%s> option %s=%f",
+                                         p_module->psz_name, p_item->psz_name,
+                                         (double)p_item->f_value );
                         break;
 
                     default:
-                        vlc_mutex_lock( p_module->p_config[i].p_lock );
+                        vlc_mutex_lock( p_item->p_lock );
 
                         /* free old string */
-                        if( p_module->p_config[i].psz_value )
-                            free( p_module->p_config[i].psz_value );
+                        if( p_item->psz_value )
+                            free( p_item->psz_value );
 
-                        p_module->p_config[i].psz_value = *psz_option_value ?
+                        p_item->psz_value = *psz_option_value ?
                             strdup( psz_option_value ) : NULL;
 
-                        vlc_mutex_unlock( p_module->p_config[i].p_lock );
+                        vlc_mutex_unlock( p_item->p_lock );
 
                         intf_WarnMsg( 7, "config: found <%s> option %s=%s",
-                                      p_module->psz_name,
-                                      p_module->p_config[i].psz_name,
-                                      p_module->p_config[i].psz_value != NULL ?
-                                        p_module->p_config[i].psz_value :
-                                        "(NULL)" );
+                                         p_module->psz_name,
+                                         p_item->psz_name,
+                                         p_item->psz_value != NULL ?
+                                           p_item->psz_value : "(NULL)" );
                         break;
                     }
                 }
@@ -429,7 +540,7 @@ int config_LoadConfigFile( const char *psz_module_name )
  * It's no use to save the config options that kept their default values, so
  * we'll try to be a bit clever here.
  *
- * When we save we mustn't delete the config options of the plugins that
+ * When we save we mustn't delete the config options of the modules that
  * haven't been loaded. So we cannot just create a new config file with the
  * config structures we've got in memory. 
  * I don't really know how to deal with this nicely, so I will use a completly
@@ -443,9 +554,10 @@ int config_LoadConfigFile( const char *psz_module_name )
 int config_SaveConfigFile( const char *psz_module_name )
 {
     module_t *p_module;
+    module_config_t *p_item;
     FILE *file;
     char p_line[1024], *p_index2;
-    int i, i_sizebuf = 0;
+    int i_sizebuf = 0;
     char *p_bigbuffer, *p_index;
     boolean_t b_backup;
     char *psz_filename, *psz_homedir;
@@ -469,12 +581,12 @@ int config_SaveConfigFile( const char *psz_module_name )
         return -1;
     }
     sprintf( psz_filename, "%s/" CONFIG_DIR, psz_homedir );
+
 #ifndef WIN32
-    i = mkdir( psz_filename, 0755 );
+    if( mkdir( psz_filename, 0755 ) && errno != EEXIST )
 #else
-    i = mkdir( psz_filename );
+    if( mkdir( psz_filename ) && errno != EEXIST )
 #endif
-    if( i && errno != EEXIST )
     {
         intf_ErrMsg( "config error: couldn't create %s (%s)",
                      psz_filename, strerror(errno) );
@@ -485,11 +597,11 @@ int config_SaveConfigFile( const char *psz_module_name )
 
     intf_WarnMsg( 5, "config: opening config file %s", psz_filename );
 
-    file = fopen( psz_filename, "r" );
+    file = fopen( psz_filename, "rt" );
     if( !file )
     {
-        intf_WarnMsg( 1, "config: couldn't open config file %s for reading (%s)",
-                         psz_filename, strerror(errno) );
+        intf_WarnMsg( 1, "config: config file %s doesn't already exist",
+                         psz_filename );
     }
     else
     {
@@ -565,7 +677,7 @@ int config_SaveConfigFile( const char *psz_module_name )
      * Save module config in file
      */
 
-    file = fopen( psz_filename, "w" );
+    file = fopen( psz_filename, "wt" );
     if( !file )
     {
         intf_WarnMsg( 1, "config: couldn't open config file %s for writing",
@@ -591,35 +703,46 @@ int config_SaveConfigFile( const char *psz_module_name )
         intf_WarnMsg( 5, "config: saving config for module <%s>",
                          p_module->psz_name );
 
-        fprintf( file, "[%s]\n", p_module->psz_name );
-
+        fprintf( file, "[%s]", p_module->psz_name );
         if( p_module->psz_longname )
-            fprintf( file, "###\n###  %s\n###\n", p_module->psz_longname );
+            fprintf( file, " # %s\n\n", p_module->psz_longname );
+        else
+            fprintf( file, "\n\n" );
 
-        for( i = 0; i < p_module->i_config_lines; i++ )
+        for( p_item = p_module->p_config;
+             p_item->i_type != MODULE_CONFIG_HINT_END;
+             p_item++ )
         {
-            if( p_module->p_config[i].i_type & MODULE_CONFIG_HINT )
+            if( p_item->i_type & MODULE_CONFIG_HINT )
                 /* ignore hints */
                 continue;
 
-            switch( p_module->p_config[i].i_type )
+            switch( p_item->i_type )
             {
             case MODULE_CONFIG_ITEM_BOOL:
             case MODULE_CONFIG_ITEM_INTEGER:
-                if( p_module->p_config[i].psz_text )
-                    fprintf( file, "# %s %s\n", p_module->p_config[i].psz_text,
-                             MODULE_CONFIG_ITEM_BOOL?"<boolean>":"<integer>" );
-                fprintf( file, "%s=%i\n", p_module->p_config[i].psz_name,
-                         p_module->p_config[i].i_value );
+                if( p_item->psz_text )
+                    fprintf( file, "# %s (%s)\n", p_item->psz_text,
+                             (p_item->i_type == MODULE_CONFIG_ITEM_BOOL) ?
+                             _("boolean") : _("integer") );
+                fprintf( file, "%s=%i\n", p_item->psz_name,
+                         p_item->i_value );
+                break;
+
+            case MODULE_CONFIG_ITEM_FLOAT:
+                if( p_item->psz_text )
+                    fprintf( file, "# %s (%s)\n", p_item->psz_text,
+                             _("float") );
+                fprintf( file, "%s=%f\n", p_item->psz_name,
+                         (double)p_item->f_value );
                 break;
 
             default:
-                if( p_module->p_config[i].psz_text )
-                    fprintf( file, "# %s <string>\n",
-                             p_module->p_config[i].psz_text );
-                fprintf( file, "%s=%s\n", p_module->p_config[i].psz_name,
-                         p_module->p_config[i].psz_value?
-                         p_module->p_config[i].psz_value:"" );
+                if( p_item->psz_text )
+                    fprintf( file, "# %s (%s)\n", p_item->psz_text,
+                             _("string") );
+                fprintf( file, "%s=%s\n", p_item->psz_name,
+                         p_item->psz_value ? p_item->psz_value : "" );
             }
         }
 
@@ -652,12 +775,17 @@ int config_SaveConfigFile( const char *psz_module_name )
 int config_LoadCmdLine( int *pi_argc, char *ppsz_argv[],
                         boolean_t b_ignore_errors )
 {
-    int i_cmd, i, i_index, i_longopts_size;
+    int i_cmd, i_index, i_opts, i_shortopts;
     module_t *p_module;
+    module_config_t *p_item;
     struct option *p_longopts;
 
     /* Short options */
-    const char *psz_shortopts = "hHvlp:";
+    module_config_t *pp_shortopts[256];
+    char *psz_shortopts;
+
+    /* Reset warning level */
+    p_main->i_warning_level = 0;
 
     /* Set default configuration and copy arguments */
     p_main->i_argc    = *pi_argc;
@@ -685,51 +813,99 @@ int config_LoadCmdLine( int *pi_argc, char *ppsz_argv[],
     }
 #endif
 
-
     /*
-     * Generate the longopts structure used by getopt_long
+     * Generate the longopts and shortopts structures used by getopt_long
      */
-    i_longopts_size = 0;
+
+    i_opts = 0;
     for( p_module = p_module_bank->first;
          p_module != NULL ;
          p_module = p_module->next )
     {
         /* count the number of exported configuration options (to allocate
          * longopts). */
-        i_longopts_size += p_module->i_config_items;
+        i_opts += p_module->i_config_items;
     }
 
-    p_longopts = (struct option *)malloc( sizeof(struct option)
-                                          * (i_longopts_size + 1) );
+    p_longopts = malloc( sizeof(struct option) * (i_opts + 1) );
     if( p_longopts == NULL )
     {
         intf_ErrMsg( "config error: couldn't allocate p_longopts" );
         return( -1 );
     }
 
-    /* Fill the longopts structure */
+    psz_shortopts = malloc( sizeof( char ) * (2 * i_opts + 1) );
+    if( psz_shortopts == NULL )
+    {
+        intf_ErrMsg( "config error: couldn't allocate psz_shortopts" );
+        free( p_longopts );
+        return( -1 );
+    }
+
+    /* If we are requested to ignore errors, then we must work on a copy
+     * of the ppsz_argv array, otherwise getopt_long will reorder it for
+     * us, ignoring the arity of the options */
+    if( b_ignore_errors )
+    {
+        ppsz_argv = (char**)malloc( *pi_argc * sizeof(char *) );
+        if( ppsz_argv == NULL )
+        {
+            intf_ErrMsg( "config error: couldn't duplicate ppsz_argv" );
+            free( psz_shortopts );
+            free( p_longopts );
+            return -1;
+        }
+        memcpy( ppsz_argv, p_main->ppsz_argv, *pi_argc * sizeof(char *) );
+    }
+
+    psz_shortopts[0] = 'v';
+    i_shortopts = 1;
+    for( i_index = 0; i_index < 256; i_index++ )
+    {
+        pp_shortopts[i_index] = NULL;
+    }
+
+    /* Fill the p_longopts and psz_shortopts structures */
     i_index = 0;
     for( p_module = p_module_bank->first ;
          p_module != NULL ;
          p_module = p_module->next )
     {
-        for( i = 0; i < p_module->i_config_lines; i++ )
+        for( p_item = p_module->p_config;
+             p_item->i_type != MODULE_CONFIG_HINT_END;
+             p_item++ )
         {
-            if( p_module->p_config[i].i_type & MODULE_CONFIG_HINT )
-                /* ignore hints */
+            /* Ignore hints */
+            if( p_item->i_type & MODULE_CONFIG_HINT )
                 continue;
-            p_longopts[i_index].name = p_module->p_config[i].psz_name;
+
+            /* Add item to long options */
+            p_longopts[i_index].name = p_item->psz_name;
             p_longopts[i_index].has_arg =
-                (p_module->p_config[i].i_type == MODULE_CONFIG_ITEM_BOOL)?
+                (p_item->i_type == MODULE_CONFIG_ITEM_BOOL)?
                                                no_argument : required_argument;
             p_longopts[i_index].flag = 0;
             p_longopts[i_index].val = 0;
             i_index++;
+
+            /* If item also has a short option, add it */
+            if( p_item->i_short )
+            {
+                pp_shortopts[(int)p_item->i_short] = p_item;
+                psz_shortopts[i_shortopts] = p_item->i_short;
+                i_shortopts++;
+                if( p_item->i_type != MODULE_CONFIG_ITEM_BOOL )
+                {
+                    psz_shortopts[i_shortopts] = ':';
+                    i_shortopts++;
+                }
+            }
         }
     }
-    /* Close the longopts structure */
-    memset( &p_longopts[i_index], 0, sizeof(struct option) );
 
+    /* Close the longopts and shortopts structures */
+    memset( &p_longopts[i_index], 0, sizeof(struct option) );
+    psz_shortopts[i_shortopts] = '\0';
 
     /*
      * Parse the command line options
@@ -739,11 +915,9 @@ int config_LoadCmdLine( int *pi_argc, char *ppsz_argv[],
     while( ( i_cmd = getopt_long( *pi_argc, ppsz_argv, psz_shortopts,
                                   p_longopts, &i_index ) ) != EOF )
     {
-
+        /* A long option has been recognized */
         if( i_cmd == 0 )
         {
-            /* A long option has been recognized */
-
             module_config_t *p_conf;
 
             /* Store the configuration option */
@@ -753,12 +927,16 @@ int config_LoadCmdLine( int *pi_argc, char *ppsz_argv[],
             {
             case MODULE_CONFIG_ITEM_STRING:
             case MODULE_CONFIG_ITEM_FILE:
-            case MODULE_CONFIG_ITEM_PLUGIN:
+            case MODULE_CONFIG_ITEM_MODULE:
                 config_PutPszVariable( p_longopts[i_index].name, optarg );
                 break;
             case MODULE_CONFIG_ITEM_INTEGER:
                 config_PutIntVariable( p_longopts[i_index].name, atoi(optarg));
                 break;
+            case MODULE_CONFIG_ITEM_FLOAT:
+                config_PutFloatVariable( p_longopts[i_index].name,
+                                         (float)atof(optarg) );
+                break;
             case MODULE_CONFIG_ITEM_BOOL:
                 config_PutIntVariable( p_longopts[i_index].name, 1 );
                 break;
@@ -767,51 +945,63 @@ int config_LoadCmdLine( int *pi_argc, char *ppsz_argv[],
             continue;
         }
 
-        /* short options handled here for now */
-        switch( i_cmd )
+        /* A short option has been recognized */
+        if( pp_shortopts[i_cmd] != NULL )
         {
-
-        /* General/common options */
-        case 'h':                                              /* -h, --help */
-            config_PutIntVariable( "help", 1 );
-            break;
-        case 'H':                                          /* -H, --longhelp */
-            config_PutIntVariable( "longhelp", 1 );
-            break;
-        case 'l':                                              /* -l, --list */
-            config_PutIntVariable( "list", 1 );
-            break;
-        case 'p':                                            /* -p, --plugin */
-            config_PutPszVariable( "plugin", optarg );
-            break;
-        case 'v':                                           /* -v, --verbose */
-            p_main->i_warning_level++;
-            break;
-
-        /* Internal error: unknown option */
-        case '?':
-        default:
-
-            if( !b_ignore_errors )
+            switch( pp_shortopts[i_cmd]->i_type )
             {
-                intf_ErrMsg( "config error: unknown option `%s'",
-                             ppsz_argv[optind-1] );
-                intf_Msg( "Try `%s --help' for more information.\n",
-                          p_main->psz_arg0 );
-
-                free( p_longopts );
-                return( -1 );
+            case MODULE_CONFIG_ITEM_STRING:
+            case MODULE_CONFIG_ITEM_FILE:
+            case MODULE_CONFIG_ITEM_MODULE:
+                config_PutPszVariable( pp_shortopts[i_cmd]->psz_name, optarg );
+                break;
+            case MODULE_CONFIG_ITEM_INTEGER:
+                config_PutIntVariable( pp_shortopts[i_cmd]->psz_name,
+                                       atoi(optarg));
+                break;
+            case MODULE_CONFIG_ITEM_BOOL:
+                config_PutIntVariable( pp_shortopts[i_cmd]->psz_name, 1 );
+                break;
             }
+
+            continue;
         }
 
-    }
+        /* Either it's a -v or it's an unknown short option */
+        if( i_cmd == 'v' )
+        {
+            p_main->i_warning_level++;
+            continue;
+        }
 
-    if( p_main->i_warning_level < 0 )
-    {
-        p_main->i_warning_level = 0;
+        /* Internal error: unknown option */
+        if( !b_ignore_errors )
+        {
+            intf_ErrMsg( "config error: unknown option `%s'",
+                         ppsz_argv[optind-1] );
+            intf_Msg( "Try `%s --help' for more information.\n",
+                      p_main->psz_arg0 );
+
+            free( p_longopts );
+            free( psz_shortopts );
+            if( b_ignore_errors ) free( ppsz_argv );
+            return( -1 );
+        }
     }
 
     free( p_longopts );
+    free( psz_shortopts );
+    if( b_ignore_errors ) free( ppsz_argv );
+
+    /* Update the warning level */
+    if( !p_main->i_warning_level )
+    {
+        p_main->i_warning_level += config_GetIntVariable( "warning" );
+    }
+    p_main->i_warning_level = ( p_main->i_warning_level < 0 ) ? 0 :
+        p_main->i_warning_level;
+    config_PutIntVariable( "warning", p_main->i_warning_level );
+
     return( 0 );
 }
 
@@ -830,6 +1020,45 @@ char *config_GetHomeDir( void )
     struct passwd *p_pw = NULL;
 #endif
 
+#ifdef WIN32
+    typedef HRESULT (WINAPI *SHGETFOLDERPATH)( HWND, int, HANDLE, DWORD,
+                                               LPTSTR );
+#   define CSIDL_FLAG_CREATE 0x8000
+#   define CSIDL_APPDATA 0x1A
+#   define SHGFP_TYPE_CURRENT 0
+
+    HINSTANCE shfolder_dll;
+    SHGETFOLDERPATH SHGetFolderPath ;
+
+    /* load the shell32 dll to retreive SHGetFolderPath */
+    if( ( shfolder_dll = LoadLibrary("shfolder.dll") ) != NULL )
+    {
+        SHGetFolderPath = (void *)GetProcAddress( shfolder_dll,
+                                                  "SHGetFolderPathA" );
+        if ( SHGetFolderPath != NULL )
+        {
+            p_homedir = (char *)malloc( MAX_PATH );
+            if( !p_homedir )
+            {
+                intf_ErrMsg( "config error: couldn't malloc p_homedir" );
+                return NULL;
+            }
+
+            /* get the "Application Data" folder for the current user */
+            if( S_OK == SHGetFolderPath( NULL,
+                                         CSIDL_APPDATA | CSIDL_FLAG_CREATE,
+                                         NULL, SHGFP_TYPE_CURRENT,
+                                         p_homedir ) )
+            {
+                FreeLibrary( shfolder_dll );
+                return p_homedir;
+            }
+            free( p_homedir );
+        }
+        FreeLibrary( shfolder_dll );
+    }
+#endif
+
 #if defined(HAVE_GETPWUID)
     if( ( p_pw = getpwuid( getuid() ) ) == NULL )
 #endif
