@@ -5,7 +5,7 @@
  * thread, and destroy a previously oppened video output thread.
  *****************************************************************************
  * Copyright (C) 2000-2001 VideoLAN
- * $Id: video_output.c,v 1.171 2002/04/05 01:05:22 gbazin Exp $
+ * $Id: video_output.c,v 1.177 2002/05/19 23:51:37 massiot Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *
@@ -265,6 +265,68 @@ void vout_DestroyThread( vout_thread_t *p_vout, int *pi_status )
     }
 }
 
+/*****************************************************************************
+ * vout_ChromaCmp: compare two chroma values
+ *****************************************************************************
+ * This function returns 1 if the two fourcc values given as argument are
+ * the same format (eg. UYVY / UYNV) or almost the same format (eg. I420/YV12)
+ *****************************************************************************/
+int vout_ChromaCmp( u32 i_chroma, u32 i_amorhc )
+{
+    /* If they are the same, they are the same ! */
+    if( i_chroma == i_amorhc )
+    {
+        return 1;
+    }
+
+    /* Check for equivalence classes */
+    switch( i_chroma )
+    {
+        case FOURCC_I420:
+        case FOURCC_IYUV:
+        case FOURCC_YV12:
+            switch( i_amorhc )
+            {
+                case FOURCC_I420:
+                case FOURCC_IYUV:
+                case FOURCC_YV12:
+                    return 1;
+
+                default:
+                    return 0;
+            }
+
+        case FOURCC_UYVY:
+        case FOURCC_UYNV:
+        case FOURCC_Y422:
+            switch( i_amorhc )
+            {
+                case FOURCC_UYVY:
+                case FOURCC_UYNV:
+                case FOURCC_Y422:
+                    return 1;
+
+                default:
+                    return 0;
+            }
+
+        case FOURCC_YUY2:
+        case FOURCC_YUNV:
+            switch( i_amorhc )
+            {
+                case FOURCC_YUY2:
+                case FOURCC_YUNV:
+                    return 1;
+
+                default:
+                    return 0;
+            }
+
+        default:
+            return 0;
+    }
+}
+
 /*****************************************************************************
  * InitThread: initialize video output thread
  *****************************************************************************
@@ -371,6 +433,7 @@ static int InitThread( vout_thread_t *p_vout )
         }
 
 #define f p_vout->chroma.p_module->p_functions->chroma.functions.chroma
+        p_vout->chroma.pf_init       = f.pf_init;
         p_vout->chroma.pf_end        = f.pf_end;
 #undef f
 
@@ -508,12 +571,37 @@ static void RunThread( vout_thread_t *p_vout)
                     p_picture->i_status = DESTROYED_PICTURE;
                     p_vout->i_heap_size--;
                 }
-                intf_WarnMsg( 1, "vout warning: late picture skipped (%p)",
-                              p_picture );
+                intf_WarnMsg( 1, "vout warning: late picture skipped (%lld)",
+                              current_date - display_date );
                 vlc_mutex_unlock( &p_vout->picture_lock );
 
                 continue;
             }
+#if 0
+            /* Removed because it causes problems for some people --Meuuh */
+            else if( display_date > current_date + VOUT_BOGUS_DELAY )
+            {
+                /* Picture is waaay too early: it will be destroyed */
+                vlc_mutex_lock( &p_vout->picture_lock );
+                if( p_picture->i_refcount )
+                {
+                    /* Pretend we displayed the picture, but don't destroy
+                     * it since the decoder might still need it. */
+                    p_picture->i_status = DISPLAYED_PICTURE;
+                }
+                else
+                {
+                    /* Destroy the picture without displaying it */
+                    p_picture->i_status = DESTROYED_PICTURE;
+                    p_vout->i_heap_size--;
+                }
+                intf_WarnMsg( 1, "vout warning: early picture skipped (%lld)",
+                              display_date - current_date );
+                vlc_mutex_unlock( &p_vout->picture_lock );
+
+                continue;
+            }
+#endif
             else if( display_date > current_date + VOUT_DISPLAY_DELAY )
             {
                 /* A picture is ready to be rendered, but its rendering date
@@ -598,11 +686,39 @@ static void RunThread( vout_thread_t *p_vout)
          */
         if( p_vout->pf_manage( p_vout ) )
         {
-            /* A fatal error occured, and the thread must terminate immediately,
-             * without displaying anything - setting b_error to 1 causes the
-             * immediate end of the main while() loop. */
+            /* A fatal error occured, and the thread must terminate
+             * immediately, without displaying anything - setting b_error to 1
+             * causes the immediate end of the main while() loop. */
             p_vout->b_error = 1;
         }
+
+        if( p_vout->i_changes & VOUT_SIZE_CHANGE )
+        {
+            /* this must only happen when the vout plugin is incapable of
+             * rescaling the picture itself. In this case we need to destroy
+             * the current picture buffers and recreate new ones with the right
+             * dimensions */
+            int i;
+
+            p_vout->i_changes &= ~VOUT_SIZE_CHANGE;
+
+            p_vout->pf_end( p_vout );
+            for( i = 0; i < I_OUTPUTPICTURES; i++ )
+                 p_vout->p_picture[ i ].i_status = FREE_PICTURE;
+
+            I_OUTPUTPICTURES = 0;
+            if( p_vout->pf_init( p_vout ) )
+            {
+                intf_ErrMsg( "vout error: cannot resize display" );
+                /* FixMe: p_vout->pf_end will be called again in EndThread() */
+                p_vout->b_error = 1;
+            }
+
+            /* Need to reinitialise the chroma plugin */
+            p_vout->chroma.pf_end( p_vout );
+            p_vout->chroma.pf_init( p_vout );
+        }
+
     }
 
     /*
@@ -812,47 +928,51 @@ static void MaskToShift( int *pi_left, int *pi_right, u32 i_mask )
 /*****************************************************************************
  * InitWindowSize: find the initial dimensions the video window should have.
  *****************************************************************************
- * This function will check the "width" and "height" config options and
+ * This function will check the "width", "height" and "zoom" config options and
  * will calculate the size that the video window should have.
  *****************************************************************************/
 static void InitWindowSize( vout_thread_t *p_vout, int *pi_width,
                             int *pi_height )
 {
     int i_width, i_height;
+    double f_zoom;
 
     i_width = config_GetIntVariable( "width" );
     i_height = config_GetIntVariable( "height" );
+    f_zoom = config_GetFloatVariable( "zoom" );
 
     if( (i_width >= 0) && (i_height >= 0))
     {
-        *pi_width = i_width;
-        *pi_height = i_height;
+        *pi_width = i_width * f_zoom;
+        *pi_height = i_height * f_zoom;
         return;
     }
     else if( i_width >= 0 )
     {
-        *pi_width = i_width;
-        *pi_height = i_width * VOUT_ASPECT_FACTOR / p_vout->render.i_aspect;
+        *pi_width = i_width * f_zoom;
+        *pi_height = i_width * f_zoom * VOUT_ASPECT_FACTOR /
+                        p_vout->render.i_aspect;
         return;
     }
     else if( i_height >= 0 )
     {
-        *pi_height = i_height;
-        *pi_width = i_height * p_vout->render.i_aspect / VOUT_ASPECT_FACTOR;
+        *pi_height = i_height * f_zoom;
+        *pi_width = i_height * f_zoom * p_vout->render.i_aspect /
+                       VOUT_ASPECT_FACTOR;
         return;
     }
 
     if( p_vout->render.i_height * p_vout->render.i_aspect
         >= p_vout->render.i_width * VOUT_ASPECT_FACTOR )
     {
-        *pi_width = p_vout->render.i_height
+        *pi_width = p_vout->render.i_height * f_zoom
           * p_vout->render.i_aspect / VOUT_ASPECT_FACTOR;
-        *pi_height = p_vout->render.i_height;
+        *pi_height = p_vout->render.i_height * f_zoom;
     }
     else
     {
-        *pi_width = p_vout->render.i_width;
-        *pi_height = p_vout->render.i_width
+        *pi_width = p_vout->render.i_width * f_zoom;
+        *pi_height = p_vout->render.i_width * f_zoom
           * VOUT_ASPECT_FACTOR / p_vout->render.i_aspect;
     }
 }
