@@ -2,7 +2,7 @@
  * vout_pictures.c : picture management functions
  *****************************************************************************
  * Copyright (C) 2000 VideoLAN
- * $Id: vout_pictures.c,v 1.21 2002/04/15 23:04:08 massiot Exp $
+ * $Id: vout_pictures.c,v 1.25 2002/05/20 19:34:58 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -35,6 +35,11 @@
 #include "video.h"
 #include "video_output.h"
 
+/*****************************************************************************
+ * Local prototypes
+ *****************************************************************************/
+static void vout_CopyPicture( picture_t *p_src, picture_t *p_dest );
+
 /*****************************************************************************
  * vout_DisplayPicture: display a picture
  *****************************************************************************
@@ -471,14 +476,23 @@ void vout_AllocatePicture( picture_t *p_pic,
             p_pic->i_planes = 1;
             break;
 
+        case FOURCC_YUY2:
+            p_pic->p->i_lines = i_height;
+            p_pic->p->i_pitch = i_width * 2;
+            p_pic->p->i_visible_bytes = p_pic->p->i_pitch;
+            p_pic->p->i_pixel_bytes = 4;
+            p_pic->i_planes = 1;
+            break;
+
         case FOURCC_RV15:
             p_pic->p->i_lines = i_height;
             p_pic->p->i_pitch = i_width * 2;
             p_pic->p->i_visible_bytes = p_pic->p->i_pitch;
             p_pic->p->i_pixel_bytes = 2;
+/* FIXME: p_heap isn't always reachable
             p_pic->p_heap->i_rmask = 0x001f;
             p_pic->p_heap->i_gmask = 0x03e0;
-            p_pic->p_heap->i_bmask = 0x7c00;
+            p_pic->p_heap->i_bmask = 0x7c00; */
             p_pic->i_planes = 1;
             break;
 
@@ -487,9 +501,10 @@ void vout_AllocatePicture( picture_t *p_pic,
             p_pic->p->i_pitch = i_width * 2;
             p_pic->p->i_visible_bytes = p_pic->p->i_pitch;
             p_pic->p->i_pixel_bytes = 2;
+/* FIXME: p_heap isn't always reachable
             p_pic->p_heap->i_rmask = 0x001f;
             p_pic->p_heap->i_gmask = 0x07e0;
-            p_pic->p_heap->i_bmask = 0xf800;
+            p_pic->p_heap->i_bmask = 0xf800; */
             p_pic->i_planes = 1;
             break;
 
@@ -498,9 +513,10 @@ void vout_AllocatePicture( picture_t *p_pic,
             p_pic->p->i_pitch = i_width * 4;
             p_pic->p->i_visible_bytes = p_pic->p->i_pitch;
             p_pic->p->i_pixel_bytes = 4;
+/* FIXME: p_heap isn't always reachable
             p_pic->p_heap->i_rmask = 0xff0000;
             p_pic->p_heap->i_gmask = 0x00ff00;
-            p_pic->p_heap->i_bmask = 0x0000ff;
+            p_pic->p_heap->i_bmask = 0x0000ff; */
             p_pic->i_planes = 1;
             break;
 
@@ -517,7 +533,7 @@ void vout_AllocatePicture( picture_t *p_pic,
         i_bytes += p_pic->p[ i_index ].i_lines * p_pic->p[ i_index ].i_pitch;
     }
 
-    p_pic->p_data = vlc_memalign( 16, i_bytes, &p_pic->p_data_orig );
+    p_pic->p_data = vlc_memalign( &p_pic->p_data_orig, 16, i_bytes );
 
     if( p_pic->p_data == NULL )
     {
@@ -536,3 +552,63 @@ void vout_AllocatePicture( picture_t *p_pic,
     }
 }
 
+/* Following functions are local */
+
+/*****************************************************************************
+ * vout_CopyPicture: copy a picture to another one
+ *****************************************************************************
+ * This function takes advantage of the image format, and reduces the
+ * number of calls to memcpy() to the minimum. Source and destination
+ * images must have same width, height, and chroma.
+ *****************************************************************************/
+static void vout_CopyPicture( picture_t *p_src, picture_t *p_dest )
+{
+    int i;
+
+    for( i = 0; i < p_src->i_planes ; i++ )
+    {
+        if( p_src->p[i].i_pitch == p_dest->p[i].i_pitch )
+        {
+            if( p_src->p[i].b_margin )
+            {
+                /* If p_src->b_margin is set, p_dest->b_margin must be set */
+                if( p_dest->p[i].b_hidden )
+                {
+                    /* There are margins, but they are hidden : perfect ! */
+                    FAST_MEMCPY( p_dest->p[i].p_pixels, p_src->p[i].p_pixels,
+                                 p_src->p[i].i_pitch * p_src->p[i].i_lines );
+                    continue;
+                }
+                else
+                {
+                    /* We can't directly copy the margin. Too bad. */
+                }
+            }
+            else
+            {
+                /* Same pitch, no margins : perfect ! */
+                FAST_MEMCPY( p_dest->p[i].p_pixels, p_src->p[i].p_pixels,
+                             p_src->p[i].i_pitch * p_src->p[i].i_lines );
+                continue;
+            }
+        }
+        else
+        {
+            /* Pitch values are different */
+        }
+
+        /* We need to proceed line by line */
+        {
+            u8 *p_in = p_src->p[i].p_pixels, *p_out = p_dest->p[i].p_pixels;
+            int i_line;
+
+            for( i_line = p_src->p[i].i_lines; i_line--; )
+            {
+                FAST_MEMCPY( p_out, p_in, p_src->p[i].i_visible_bytes );
+                p_in += p_src->p[i].i_pitch;
+                p_out += p_dest->p[i].i_pitch;
+            }
+        }
+    }
+}
+
